# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/flat_scheme_op.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import pqconfig_pb2 as ydb_dot_core_dot_protos_dot_pqconfig__pb2
from ydb.core.protos import replication_pb2 as ydb_dot_core_dot_protos_dot_replication__pb2
from ydb.core.protos import table_stats_pb2 as ydb_dot_core_dot_protos_dot_table__stats__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import blockstore_config_pb2 as ydb_dot_core_dot_protos_dot_blockstore__config__pb2
from ydb.core.protos import filestore_config_pb2 as ydb_dot_core_dot_protos_dot_filestore__config__pb2
from ydb.core.protos import channel_purpose_pb2 as ydb_dot_core_dot_protos_dot_channel__purpose__pb2
from ydb.core.protos import follower_group_pb2 as ydb_dot_core_dot_protos_dot_follower__group__pb2
from ydb.core.protos import blob_depot_config_pb2 as ydb_dot_core_dot_protos_dot_blob__depot__config__pb2
from ydb.public.api.protos import ydb_coordination_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__coordination__pb2
from ydb.public.api.protos import ydb_export_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__export__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/flat_scheme_op.proto\x12\x0fNKikimrSchemeOp\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/type_info.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a\x1eydb/core/protos/pqconfig.proto\x1a!ydb/core/protos/replication.proto\x1a!ydb/core/protos/table_stats.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a\'ydb/core/protos/blockstore_config.proto\x1a&ydb/core/protos/filestore_config.proto\x1a%ydb/core/protos/channel_purpose.proto\x1a$ydb/core/protos/follower_group.proto\x1a\'ydb/core/protos/blob_depot_config.proto\x1a,ydb/public/api/protos/ydb_coordination.proto\x1a&ydb/public/api/protos/ydb_export.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x16\n\x06TMkDir\x12\x0c\n\x04Name\x18\x01 \x01(\t\"W\n\x05TDrop\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x34\n\nWaitPolicy\x18\x02 \x01(\x0e\x32 .NKikimrSchemeOp.EDropWaitPolicy\x12\n\n\x02Id\x18\x03 \x01(\x04\"\xdb\x01\n\x12TColumnDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0e\n\x06TypeId\x18\x03 \x01(\r\x12)\n\x08TypeInfo\x18\t \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\n\n\x02Id\x18\x04 \x01(\r\x12\x0e\n\x06\x46\x61mily\x18\x05 \x01(\r\x12\x12\n\nFamilyName\x18\x06 \x01(\t\x12\x1d\n\x13\x44\x65\x66\x61ultFromSequence\x18\x07 \x01(\tH\x00\x12\x0f\n\x07NotNull\x18\x08 \x01(\x08\x42\x0e\n\x0c\x44\x65\x66\x61ultValue\"L\n\x10TStorageSettings\x12\x19\n\x11PreferredPoolKind\x18\x01 \x01(\t\x12\x1d\n\x0f\x41llowOtherKinds\x18\x02 \x01(\x08:\x04true\"\x8b\x02\n\x0eTStorageConfig\x12\x31\n\x06SysLog\x18\x01 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12.\n\x03Log\x18\x02 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12/\n\x04\x44\x61ta\x18\x03 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12\x33\n\x08\x45xternal\x18\x04 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12\x15\n\rDataThreshold\x18\x05 \x01(\r\x12\x19\n\x11\x45xternalThreshold\x18\x06 \x01(\r\"\xaf\x02\n\x12TFamilyDescription\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Room\x18\x02 \x01(\r\x12\r\n\x05\x43odec\x18\x03 \x01(\r\x12\x10\n\x08InMemory\x18\x04 \x01(\x08\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x32\n\x0b\x43olumnCodec\x18\x06 \x01(\x0e\x32\x1d.NKikimrSchemeOp.EColumnCodec\x12\x32\n\x0b\x43olumnCache\x18\x07 \x01(\x0e\x32\x1d.NKikimrSchemeOp.EColumnCache\x12\x30\n\x07Storage\x18\x08 \x01(\x0e\x32\x1f.NKikimrSchemeOp.EColumnStorage\x12\x36\n\rStorageConfig\x18\t \x01(\x0b\x32\x1f.NKikimrSchemeOp.TStorageConfig\"\x9c\x10\n\x11TCompactionPolicy\x12\x1b\n\x13InMemSizeToSnapshot\x18\x01 \x01(\x04\x12\x1c\n\x14InMemStepsToSnapshot\x18\x02 \x01(\r\x12!\n\x19InMemForceStepsToSnapshot\x18\x03 \x01(\r\x12 \n\x18InMemForceSizeToSnapshot\x18\x04 \x01(\x04\x12%\n\x1aInMemCompactionBrokerQueue\x18\x05 \x01(\r:\x01\x30\x12&\n\x14ReadAheadHiThreshold\x18\x06 \x01(\x04:\x08\x36\x37\x31\x30\x38\x38\x36\x34\x12&\n\x14ReadAheadLoThreshold\x18\x07 \x01(\x04:\x08\x31\x36\x37\x37\x37\x32\x31\x36\x12\x1d\n\x0fMinDataPageSize\x18\x08 \x01(\r:\x04\x37\x31\x36\x38\x12\x1a\n\x0fSnapBrokerQueue\x18\t \x01(\r:\x01\x30\x12\x1c\n\x11\x42\x61\x63kupBrokerQueue\x18\x0b \x01(\r:\x01\x31\x12\x1e\n\x13\x44\x65\x66\x61ultTaskPriority\x18\x0c \x01(\r:\x01\x35\x12V\n\x18\x42\x61\x63kgroundSnapshotPolicy\x18\r \x01(\x0b\x32\x34.NKikimrSchemeOp.TCompactionPolicy.TBackgroundPolicy\x12\x1f\n\x17InMemResourceBrokerTask\x18\x0e \x01(\t\x12\"\n\x1aSnapshotResourceBrokerTask\x18\x0f \x01(\t\x12 \n\x18\x42\x61\x63kupResourceBrokerTask\x18\x10 \x01(\t\x12!\n\x19LogOverheadSizeToSnapshot\x18\x11 \x01(\x04\x12\"\n\x1aLogOverheadCountToSnapshot\x18\x12 \x01(\r\x12#\n\x1b\x44roppedRowsPercentToCompact\x18\x13 \x01(\r\x12Y\n\x12\x43ompactionStrategy\x18\x14 \x01(\x0e\x32$.NKikimrSchemeOp.ECompactionStrategy:\x17\x43ompactionStrategyUnset\x12\x44\n\x0bShardPolicy\x18\x15 \x01(\x0b\x32/.NKikimrSchemeOp.TCompactionPolicy.TShardPolicy\x12\x18\n\x10KeepEraseMarkers\x18\x16 \x01(\x08\x12H\n\nGeneration\x18\n \x03(\x0b\x32\x34.NKikimrSchemeOp.TCompactionPolicy.TGenerationPolicy\x1a\x8e\x01\n\x11TBackgroundPolicy\x12\x16\n\tThreshold\x18\x01 \x01(\r:\x03\x31\x30\x31\x12\x19\n\x0cPriorityBase\x18\x02 \x01(\r:\x03\x31\x30\x30\x12\x15\n\nTimeFactor\x18\x03 \x01(\x01:\x01\x31\x12\x13\n\x08TaskType\x18\x04 \x01(\r:\x01\x35\x12\x1a\n\x12ResourceBrokerTask\x18\x05 \x01(\t\x1a\xd9\x03\n\x11TGenerationPolicy\x12\x14\n\x0cGenerationId\x18\x01 \x01(\r\x12\x15\n\rSizeToCompact\x18\x02 \x01(\x04\x12\x16\n\x0e\x43ountToCompact\x18\x03 \x01(\r\x12\x1b\n\x13\x46orceCountToCompact\x18\x04 \x01(\r\x12\x1a\n\x12\x46orceSizeToCompact\x18\x05 \x01(\x04\x12\x1d\n\x15\x43ompactionBrokerQueue\x18\x06 \x01(\r\x12\x13\n\x0bKeepInCache\x18\x07 \x01(\x08\x12X\n\x1a\x42\x61\x63kgroundCompactionPolicy\x18\x08 \x01(\x0b\x32\x34.NKikimrSchemeOp.TCompactionPolicy.TBackgroundPolicy\x12\x1a\n\x12ResourceBrokerTask\x18\t \x01(\t\x12\x1e\n\x16\x45xtraCompactionPercent\x18\n \x01(\r\x12\x1e\n\x16\x45xtraCompactionMinSize\x18\x0b \x01(\x04\x12!\n\x19\x45xtraCompactionExpPercent\x18\x0c \x01(\r\x12!\n\x19\x45xtraCompactionExpMaxSize\x18\r \x01(\x04\x12\x16\n\x0eUpliftPartSize\x18\x0e \x01(\x04\x1a\xf9\x03\n\x0cTShardPolicy\x12\x1e\n\x0cMinShardSize\x18\x01 \x01(\x04:\x08\x33\x33\x35\x35\x34\x34\x33\x32\x12\x1f\n\x0cMaxShardSize\x18\x02 \x01(\x04:\t134217728\x12\x1d\n\x0cMinSliceSize\x18\x03 \x01(\x04:\x07\x32\x30\x39\x37\x31\x35\x32\x12\x1e\n\x11MaxSlicesPerLevel\x18\x04 \x01(\r:\x03\x32\x35\x36\x12\x1a\n\x0eMaxTotalLevels\x18\x05 \x01(\r:\x02\x31\x36\x12\x1d\n\x12MinLevelsToCompact\x18\x06 \x01(\r:\x01\x32\x12$\n\x17NewDataPercentToCompact\x18\x07 \x01(\r:\x03\x31\x30\x30\x12\"\n\x17NewRowsPercentToCompact\x18\x08 \x01(\r:\x01\x30\x12+\n\x12ResourceBrokerTask\x18\t \x01(\t:\x0f\x63ompaction_gen1\x12\x1e\n\x10TaskPriorityBase\x18\n \x01(\r:\x04\x31\x30\x30\x30\x12\"\n\x17TaskPriorityLevelsBoost\x18\x0b \x01(\r:\x01\x31\x12(\n\x17TaskPrioritySizePenalty\x18\x0c \x01(\x04:\x07\x34\x31\x39\x34\x33\x30\x34\x12$\n\x18MaxGarbagePercentToReuse\x18\r \x01(\r:\x02\x32\x30\x12#\n\x13MinSliceSizeToReuse\x18\x0e \x01(\x04:\x06\x35\x32\x34\x32\x38\x38\"f\n\x12TFastSplitSettings\x12\x15\n\rSizeThreshold\x18\x01 \x01(\x04\x12\x19\n\x11RowCountThreshold\x18\x02 \x01(\x04\x12\x1e\n\x16\x43puPercentageThreshold\x18\x03 \x01(\r\"G\n\x14TSplitByLoadSettings\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x1e\n\x16\x43puPercentageThreshold\x18\x02 \x01(\r\"\xe6\x01\n\x13TPartitioningPolicy\x12\x13\n\x0bSizeToSplit\x18\x01 \x01(\x04\x12\x1a\n\x12MinPartitionsCount\x18\x02 \x01(\r\x12\x1a\n\x12MaxPartitionsCount\x18\x03 \x01(\r\x12>\n\x11\x46\x61stSplitSettings\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TFastSplitSettings\x12\x42\n\x13SplitByLoadSettings\x18\x05 \x01(\x0b\x32%.NKikimrSchemeOp.TSplitByLoadSettings\"\x97\x01\n\x0fTPipelineConfig\x12\x16\n\x0bNumActiveTx\x18\x01 \x01(\r:\x01\x38\x12\x17\n\x0f\x44\x61taTxCacheSize\x18\x02 \x01(\r\x12\x1e\n\x10\x45nableOutOfOrder\x18\x03 \x01(\x08:\x04true\x12\x18\n\x10\x44isableImmediate\x18\x04 \x01(\x08\x12\x19\n\x11\x45nableSoftUpdates\x18\x05 \x01(\x08\"\x92\x07\n\x10TPartitionConfig\x12\x1d\n\x15NamedCompactionPolicy\x18\x01 \x01(\t\x12<\n\x10\x43ompactionPolicy\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TCompactionPolicy\x12\x15\n\rFollowerCount\x18\x03 \x01(\x04\x12\x19\n\x11\x45xecutorCacheSize\x18\x04 \x01(\x04\x12$\n\x16\x41llowFollowerPromotion\x18\x05 \x01(\x08:\x04true\x12\x17\n\x0fTxReadSizeLimit\x18\x06 \x01(\x04\x12$\n\x1c\x43rossDataCenterFollowerCount\x18\x08 \x01(\r\x12\x18\n\x10\x43hannelProfileId\x18\t \x01(\r\x12@\n\x12PartitioningPolicy\x18\n \x01(\x0b\x32$.NKikimrSchemeOp.TPartitioningPolicy\x12\x38\n\x0ePipelineConfig\x18\x0b \x01(\x0b\x32 .NKikimrSchemeOp.TPipelineConfig\x12;\n\x0e\x43olumnFamilies\x18\x0c \x03(\x0b\x32#.NKikimrSchemeOp.TFamilyDescription\x12\x17\n\x0fResourceProfile\x18\r \x01(\t\x12$\n\x1c\x44isableStatisticsCalculation\x18\x0e \x01(\x08\x12 \n\x11\x45nableFilterByKey\x18\x0f \x01(\x08:\x05\x66\x61lse\x12#\n\x15\x45xecutorFastLogPolicy\x18\x10 \x01(\x08:\x04true\x12:\n\x0cStorageRooms\x18\x11 \x03(\x0b\x32$.NKikimrStorageSettings.TStorageRoom\x12\x1e\n\x10\x45nableEraseCache\x18\x12 \x01(\x08:\x04true\x12\x19\n\x11\x45raseCacheMinRows\x18\x13 \x01(\r\x12\x1a\n\x12\x45raseCacheMaxBytes\x18\x14 \x01(\r\x12\x32\n\x0b\x46reezeState\x18\x15 \x01(\x0e\x32\x1d.NKikimrSchemeOp.EFreezeState\x12\x12\n\nShadowData\x18\x16 \x01(\x08\x12\x33\n\x0e\x46ollowerGroups\x18\x17 \x03(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x1b\n\x13KeepSnapshotTimeout\x18\x19 \x01(\x04J\x04\x08\x18\x10\x19\"X\n\x0eTSplitBoundary\x12)\n\tKeyPrefix\x18\x01 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12\x1b\n\x13SerializedKeyPrefix\x18\x02 \x01(\x0c\"-\n\tTShardIdx\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0f\n\x07LocalId\x18\x02 \x01(\x04\"\x9b\x05\n\x0cTTTLSettings\x12\x39\n\x07\x45nabled\x18\x01 \x01(\x0b\x32&.NKikimrSchemeOp.TTTLSettings.TEnabledH\x00\x12;\n\x08\x44isabled\x18\x02 \x01(\x0b\x32\'.NKikimrSchemeOp.TTTLSettings.TDisabledH\x00\x12\x12\n\nUseTiering\x18\x03 \x01(\t\x1a\xc2\x01\n\x0cTSysSettings\x12\x1f\n\x0bRunInterval\x18\x01 \x01(\x04:\n3600000000\x12 \n\rRetryInterval\x18\x02 \x01(\x04:\t300000000\x12\x1d\n\rBatchMaxBytes\x18\x03 \x01(\r:\x06\x35\x31\x32\x30\x30\x30\x12\x17\n\x0c\x42\x61tchMinKeys\x18\x04 \x01(\r:\x01\x31\x12\x19\n\x0c\x42\x61tchMaxKeys\x18\x05 \x01(\r:\x03\x32\x35\x36\x12\x1c\n\x11MaxShardsInFlight\x18\x06 \x01(\r:\x01\x30\x1a\xb4\x01\n\x08TEnabled\x12\x12\n\nColumnName\x18\x01 \x01(\t\x12\x1a\n\x12\x45xpireAfterSeconds\x18\x02 \x01(\r\x12\x37\n\nColumnUnit\x18\x03 \x01(\x0e\x32#.NKikimrSchemeOp.TTTLSettings.EUnit\x12?\n\x0bSysSettings\x18\x04 \x01(\x0b\x32*.NKikimrSchemeOp.TTTLSettings.TSysSettings\x1a\x0b\n\tTDisabled\"l\n\x05\x45Unit\x12\r\n\tUNIT_AUTO\x10\x00\x12\x10\n\x0cUNIT_SECONDS\x10\x01\x12\x15\n\x11UNIT_MILLISECONDS\x10\x02\x12\x15\n\x11UNIT_MICROSECONDS\x10\x03\x12\x14\n\x10UNIT_NANOSECONDS\x10\x04\x42\x08\n\x06Status\"\xf3\x06\n\x11TTableDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\rId_Deprecated\x18\x02 \x01(\x04\x12\x34\n\x07\x43olumns\x18\x03 \x03(\x0b\x32#.NKikimrSchemeOp.TColumnDescription\x12\x16\n\x0eKeyColumnNames\x18\x04 \x03(\t\x12\x14\n\x0cKeyColumnIds\x18\x05 \x03(\r\x12\x1e\n\x16UniformPartitionsCount\x18\x06 \x01(\r\x12:\n\x0fPartitionConfig\x18\x07 \x01(\x0b\x32!.NKikimrSchemeOp.TPartitionConfig\x12\x38\n\x0b\x44ropColumns\x18\x08 \x03(\x0b\x32#.NKikimrSchemeOp.TColumnDescription\x12\x0c\n\x04Path\x18\t \x01(\t\x12\x1b\n\x13PartitionRangeBegin\x18\x14 \x01(\x0c\x12\x19\n\x11PartitionRangeEnd\x18\x15 \x01(\x0c\x12&\n\x1ePartitionRangeBeginIsInclusive\x18\x16 \x01(\x08\x12$\n\x1cPartitionRangeEndIsInclusive\x18\x17 \x01(\x08\x12\x15\n\rCopyFromTable\x18\x1e \x01(\t\x12\x36\n\rSplitBoundary\x18\x1f \x03(\x0b\x32\x1f.NKikimrSchemeOp.TSplitBoundary\x12\x38\n\x0cTableIndexes\x18  \x03(\x0b\x32\".NKikimrSchemeOp.TIndexDescription\x12\x1a\n\x12TableSchemaVersion\x18! \x01(\x04\x12%\n\x06PathId\x18\" \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x32\n\x0bTTLSettings\x18# \x01(\x0b\x32\x1d.NKikimrSchemeOp.TTTLSettings\x12\x1c\n\rOmitFollowers\x18$ \x01(\x08:\x05\x66\x61lse\x12\x17\n\x08IsBackup\x18% \x01(\x08:\x05\x66\x61lse\x12:\n\nCdcStreams\x18& \x03(\x0b\x32&.NKikimrSchemeOp.TCdcStreamDescription\x12\x38\n\tSequences\x18\' \x03(\x0b\x32%.NKikimrSchemeOp.TSequenceDescription\"h\n\x13TCompressionOptions\x12\x37\n\x10\x43ompressionCodec\x18\x02 \x01(\x0e\x32\x1d.NKikimrSchemeOp.EColumnCodec\x12\x18\n\x10\x43ompressionLevel\x18\x03 \x01(\x05\"\x8c\x01\n\x16TOlapColumnDescription\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\x0e\n\x06TypeId\x18\x04 \x01(\r\x12)\n\x08TypeInfo\x18\x06 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x0f\n\x07NotNull\x18\x07 \x01(\x08\" \n\x10TAlterOlapColumn\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\x1f\n\x0fTDropOlapColumn\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\x92\x01\n\x12TStorageTierConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x33\n\rObjectStorage\x18\x02 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TS3Settings\x12\x39\n\x0b\x43ompression\x18\x03 \x01(\x0b\x32$.NKikimrSchemeOp.TCompressionOptions\"\x87\x02\n\x12TColumnTableSchema\x12\x38\n\x07\x43olumns\x18\x01 \x03(\x0b\x32\'.NKikimrSchemeOp.TOlapColumnDescription\x12\x16\n\x0eKeyColumnNames\x18\x02 \x03(\t\x12\x33\n\x06\x45ngine\x18\x03 \x01(\x0e\x32#.NKikimrSchemeOp.EColumnTableEngine\x12\x14\n\x0cNextColumnId\x18\x04 \x01(\r\x12\x12\n\x07Version\x18\x05 \x01(\x04:\x01\x31\x12@\n\x12\x44\x65\x66\x61ultCompression\x18\x08 \x01(\x0b\x32$.NKikimrSchemeOp.TCompressionOptions\"\xe1\x01\n\x17TAlterColumnTableSchema\x12;\n\nAddColumns\x18\x01 \x03(\x0b\x32\'.NKikimrSchemeOp.TOlapColumnDescription\x12\x37\n\x0c\x41lterColumns\x18\x02 \x03(\x0b\x32!.NKikimrSchemeOp.TAlterOlapColumn\x12\x35\n\x0b\x44ropColumns\x18\x03 \x03(\x0b\x32 .NKikimrSchemeOp.TDropOlapColumn\x12\x19\n\x11\x41\x64\x64KeyColumnNames\x18\x04 \x03(\t\"i\n\x18TColumnTableSchemaPreset\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x33\n\x06Schema\x18\x03 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\"l\n\x1dTAlterColumnTableSchemaPreset\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12=\n\x0b\x41lterSchema\x18\x02 \x01(\x0b\x32(.NKikimrSchemeOp.TAlterColumnTableSchema\".\n\x1eTRemoveColumnTableSchemaPreset\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\xf3\x02\n\x14TColumnDataLifeCycle\x12=\n\x07\x45nabled\x18\x01 \x01(\x0b\x32*.NKikimrSchemeOp.TColumnDataLifeCycle.TTtlH\x00\x12\x43\n\x08\x44isabled\x18\x02 \x01(\x0b\x32/.NKikimrSchemeOp.TColumnDataLifeCycle.TDisabledH\x00\x12\x12\n\x07Version\x18\x03 \x01(\x04:\x01\x31\x12\x12\n\nUseTiering\x18\x05 \x01(\t\x1a\x97\x01\n\x04TTtl\x12\x12\n\nColumnName\x18\x01 \x01(\t\x12\x1c\n\x12\x45xpireAfterSeconds\x18\x02 \x01(\rH\x00\x12\x1a\n\x10\x45xpireAfterBytes\x18\x04 \x01(\x04H\x00\x12\x37\n\nColumnUnit\x18\x03 \x01(\x0e\x32#.NKikimrSchemeOp.TTTLSettings.EUnitB\x08\n\x06\x45xpire\x1a\x0b\n\tTDisabledB\x08\n\x06Status\"u\n\x1dTColumnTableTtlSettingsPreset\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12:\n\x0bTtlSettings\x18\x03 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\"s\n\"TAlterColumnTableTtlSettingsPreset\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12?\n\x10\x41lterTtlSettings\x18\x02 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\"3\n#TRemoveColumnTableTtlSettingsPreset\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\xc4\x01\n\x14TColumnStorageConfig\x12\x31\n\x06SysLog\x18\x01 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12.\n\x03Log\x18\x02 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12/\n\x04\x44\x61ta\x18\x03 \x01(\x0b\x32!.NKikimrSchemeOp.TStorageSettings\x12\x18\n\x10\x44\x61taChannelCount\x18\x04 \x01(\r\"x\n\x14TColumnStoreSharding\x12.\n\nMetaShards\x18\x01 \x03(\x0b\x32\x1a.NKikimrSchemeOp.TShardIdx\x12\x30\n\x0c\x43olumnShards\x18\x02 \x03(\x0b\x32\x1a.NKikimrSchemeOp.TShardIdx\"\xa7\x03\n\x17TColumnStoreDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1f\n\x17RESERVED_MetaShardCount\x18\x02 \x01(\r\x12\x18\n\x10\x43olumnShardCount\x18\x03 \x01(\r\x12\x1b\n\x13RESERVED_MetaShards\x18\x04 \x03(\x04\x12\x14\n\x0c\x43olumnShards\x18\x05 \x03(\x04\x12@\n\rSchemaPresets\x18\x06 \x03(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12S\n\x1bRESERVED_TtlSettingsPresets\x18\x07 \x03(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12<\n\rStorageConfig\x18\n \x01(\x0b\x32%.NKikimrSchemeOp.TColumnStorageConfig\x12\x1a\n\x12NextSchemaPresetId\x18\x08 \x01(\r\x12\x1f\n\x17NextTtlSettingsPresetId\x18\t \x01(\r\"\x98\x04\n\x11TAlterColumnStore\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x43\n\x10\x41\x64\x64SchemaPresets\x18\x02 \x03(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12J\n\x12\x41lterSchemaPresets\x18\x03 \x03(\x0b\x32..NKikimrSchemeOp.TAlterColumnTableSchemaPreset\x12L\n\x13RemoveSchemaPresets\x18\x04 \x03(\x0b\x32/.NKikimrSchemeOp.TRemoveColumnTableSchemaPreset\x12V\n\x1eRESERVED_AddTtlSettingsPresets\x18\x05 \x03(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12]\n RESERVED_AlterTtlSettingsPresets\x18\x06 \x03(\x0b\x32\x33.NKikimrSchemeOp.TAlterColumnTableTtlSettingsPreset\x12_\n!RESERVED_RemoveTtlSettingsPresets\x18\x07 \x03(\x0b\x32\x34.NKikimrSchemeOp.TRemoveColumnTableTtlSettingsPreset\"\xa8\x04\n\x14TColumnTableSharding\x12\x0f\n\x07Version\x18\x01 \x01(\x04\x12\x14\n\x0c\x43olumnShards\x18\x02 \x03(\x04\x12\x1e\n\x16\x41\x64\x64itionalColumnShards\x18\x03 \x03(\x04\x12\x18\n\x10UniquePrimaryKey\x18\x04 \x01(\x08\x12O\n\x0eRandomSharding\x18\x05 \x01(\x0b\x32\x35.NKikimrSchemeOp.TColumnTableSharding.TRandomShardingH\x00\x12K\n\x0cHashSharding\x18\x06 \x01(\x0b\x32\x33.NKikimrSchemeOp.TColumnTableSharding.THashShardingH\x00\x1a\x11\n\x0fTRandomSharding\x1a\xf3\x01\n\rTHashSharding\x12S\n\x08\x46unction\x18\x01 \x01(\x0e\x32\x41.NKikimrSchemeOp.TColumnTableSharding.THashSharding.EHashFunction\x12\x0f\n\x07\x43olumns\x18\x02 \x03(\t\x12\x16\n\x0eUniqueShardKey\x18\x03 \x01(\x08\x12\x19\n\x11\x41\x63tiveShardsCount\x18\x04 \x01(\r\"I\n\rEHashFunction\x12\x1a\n\x16HASH_FUNCTION_MODULO_N\x10\x00\x12\x1c\n\x18HASH_FUNCTION_CLOUD_LOGS\x10\x01\x42\x08\n\x06Method\"\xa0\x04\n\x17TColumnTableDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x33\n\x06Schema\x18\x02 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12:\n\x0bTtlSettings\x18\x03 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12\x16\n\x0eSchemaPresetId\x18\x04 \x01(\r\x12$\n\x1cRESERVED_TtlSettingsPresetId\x18\x05 \x01(\r\x12\x18\n\x10SchemaPresetName\x18\x06 \x01(\t\x12&\n\x1eRESERVED_TtlSettingsPresetName\x18\x07 \x01(\t\x12\x30\n\x11\x43olumnStorePathId\x18\x08 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x18\n\x10\x43olumnShardCount\x18\t \x01(\r\x12\x37\n\x08Sharding\x18\n \x01(\x0b\x32%.NKikimrSchemeOp.TColumnTableSharding\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x0b \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\x0c \x01(\x04\x12<\n\rStorageConfig\x18\r \x01(\x0b\x32%.NKikimrSchemeOp.TColumnStorageConfig\"\xed\x01\n\x11TAlterColumnTable\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12=\n\x0b\x41lterSchema\x18\x02 \x01(\x0b\x32(.NKikimrSchemeOp.TAlterColumnTableSchema\x12?\n\x10\x41lterTtlSettings\x18\x03 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12\x1d\n\x15\x41lterSchemaPresetName\x18\x04 \x01(\t\x12+\n#RESERVED_AlterTtlSettingsPresetName\x18\x05 \x01(\t\"2\n\x10TLoginCreateUser\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\"2\n\x10TLoginModifyUser\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\" \n\x10TLoginRemoveUser\x12\x0c\n\x04User\x18\x01 \x01(\t\"\"\n\x11TLoginCreateGroup\x12\r\n\x05Group\x18\x01 \x01(\t\"9\n\x18TLoginAddGroupMembership\x12\r\n\x05Group\x18\x01 \x01(\t\x12\x0e\n\x06Member\x18\x02 \x01(\t\"<\n\x1bTLoginRemoveGroupMembership\x12\r\n\x05Group\x18\x01 \x01(\t\x12\x0e\n\x06Member\x18\x02 \x01(\t\"\"\n\x11TLoginRemoveGroup\x12\r\n\x05Group\x18\x01 \x01(\t\"\xcf\x03\n\x0bTAlterLogin\x12\x37\n\nCreateUser\x18\x01 \x01(\x0b\x32!.NKikimrSchemeOp.TLoginCreateUserH\x00\x12\x37\n\nModifyUser\x18\x02 \x01(\x0b\x32!.NKikimrSchemeOp.TLoginModifyUserH\x00\x12\x37\n\nRemoveUser\x18\x03 \x01(\x0b\x32!.NKikimrSchemeOp.TLoginRemoveUserH\x00\x12\x39\n\x0b\x43reateGroup\x18\x04 \x01(\x0b\x32\".NKikimrSchemeOp.TLoginCreateGroupH\x00\x12G\n\x12\x41\x64\x64GroupMembership\x18\x05 \x01(\x0b\x32).NKikimrSchemeOp.TLoginAddGroupMembershipH\x00\x12M\n\x15RemoveGroupMembership\x18\x06 \x01(\x0b\x32,.NKikimrSchemeOp.TLoginRemoveGroupMembershipH\x00\x12\x39\n\x0bRemoveGroup\x18\x07 \x01(\x0b\x32\".NKikimrSchemeOp.TLoginRemoveGroupH\x00\x42\x07\n\x05\x41lter\"\x91\x02\n\x15TCdcStreamDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12-\n\x04Mode\x18\x02 \x01(\x0e\x32\x1f.NKikimrSchemeOp.ECdcStreamMode\x12\x31\n\x06\x46ormat\x18\x06 \x01(\x0e\x32!.NKikimrSchemeOp.ECdcStreamFormat\x12\x19\n\x11VirtualTimestamps\x18\x07 \x01(\x08\x12%\n\x06PathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12/\n\x05State\x18\x04 \x01(\x0e\x32 .NKikimrSchemeOp.ECdcStreamState\x12\x15\n\rSchemaVersion\x18\x05 \x01(\x04\"\x8f\x01\n\x10TCreateCdcStream\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x41\n\x11StreamDescription\x18\x02 \x01(\x0b\x32&.NKikimrSchemeOp.TCdcStreamDescription\x12%\n\x16RetentionPeriodSeconds\x18\x03 \x01(\x04:\x05\x38\x36\x34\x30\x30\"\x8c\x01\n\x0fTAlterCdcStream\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x12\n\nStreamName\x18\x02 \x01(\t\x12<\n\x07\x44isable\x18\x03 \x01(\x0b\x32).NKikimrSchemeOp.TAlterCdcStream.TDisableH\x00\x1a\n\n\x08TDisableB\x08\n\x06\x41\x63tion\"7\n\x0eTDropCdcStream\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x12\n\nStreamName\x18\x02 \x01(\t\"\xfd\x01\n\x11TIndexDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x0bLocalPathId\x18\x02 \x01(\x04\x12)\n\x04Type\x18\x03 \x01(\x0e\x32\x1b.NKikimrSchemeOp.EIndexType\x12+\n\x05State\x18\x04 \x01(\x0e\x32\x1c.NKikimrSchemeOp.EIndexState\x12\x16\n\x0eKeyColumnNames\x18\x05 \x03(\t\x12\x15\n\rSchemaVersion\x18\x06 \x01(\x04\x12\x13\n\x0bPathOwnerId\x18\x07 \x01(\x04\x12\x17\n\x0f\x44\x61taColumnNames\x18\x08 \x03(\t\x12\x10\n\x08\x44\x61taSize\x18\t \x01(\x04\"\xf4\x01\n\x14TIndexCreationConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x0eKeyColumnNames\x18\x02 \x03(\t\x12)\n\x04Type\x18\x03 \x01(\x0e\x32\x1b.NKikimrSchemeOp.EIndexType\x12\x45\n\x19IndexImplTableDescription\x18\x04 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12+\n\x05State\x18\x05 \x01(\x0e\x32\x1c.NKikimrSchemeOp.EIndexState\x12\x17\n\x0f\x44\x61taColumnNames\x18\x06 \x03(\t\"Q\n\x14TIndexAlteringConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12+\n\x05State\x18\x02 \x01(\x0e\x32\x1c.NKikimrSchemeOp.EIndexState\"\xe0\x01\n\x1bTIndexedTableCreationConfig\x12<\n\x10TableDescription\x18\x01 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12?\n\x10IndexDescription\x18\x02 \x03(\x0b\x32%.NKikimrSchemeOp.TIndexCreationConfig\x12\x42\n\x13SequenceDescription\x18\x03 \x03(\x0b\x32%.NKikimrSchemeOp.TSequenceDescription\"1\n\x1cTInitiateBuildIndexMainTable\x12\x11\n\tTableName\x18\x01 \x01(\t\"\xbd\x01\n\x12TBuildIndexOutcome\x12\'\n\x05\x41pply\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12=\n\x06\x43\x61ncel\x18\x02 \x01(\x0b\x32+.NKikimrSchemeOp.TBuildIndexOutcome.TCancelH\x00\x1a\x35\n\x07TCancel\x12*\n\x0bIndexPathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathIDB\x08\n\x06Result\"\x93\x01\n\x1cTFinalizeBuildIndexMainTable\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x14\n\x0cSnapshotTxId\x18\x02 \x01(\x04\x12\x14\n\x0c\x42uildIndexId\x18\x03 \x01(\x04\x12\x34\n\x07Outcome\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TBuildIndexOutcome\"\x87\x01\n\x10TCopyTableConfig\x12\x0f\n\x07SrcPath\x18\x01 \x01(\t\x12\x0f\n\x07\x44stPath\x18\x02 \x01(\t\x12\x1a\n\x0bOmitIndexes\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\rOmitFollowers\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x08IsBackup\x18\x05 \x01(\x08:\x05\x66\x61lse\"a\n\x1dTConsistentTableCopyingConfig\x12@\n\x15\x43opyTableDescriptions\x18\x01 \x03(\x0b\x32!.NKikimrSchemeOp.TCopyTableConfig\"w\n\x0bTYTSettings\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x14\n\x0cTablePattern\x18\x02 \x01(\t\x12\r\n\x05Token\x18\x03 \x01(\t\x12\x10\n\x04Port\x18\x04 \x01(\r:\x02\x38\x30\x12\x11\n\tUseTypeV3\x18\x08 \x01(\x08J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"\xf3\x04\n\x0bTS3Settings\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12;\n\x06Scheme\x18\x02 \x01(\x0e\x32$.NKikimrSchemeOp.TS3Settings.EScheme:\x05HTTPS\x12\x0e\n\x06\x42ucket\x18\x03 \x01(\t\x12\x18\n\x10ObjectKeyPattern\x18\x04 \x01(\t\x12\x11\n\tAccessKey\x18\x05 \x01(\t\x12\x11\n\tSecretKey\x18\x06 \x01(\t\x12\x41\n\x0cStorageClass\x18\x07 \x01(\x0e\x32+.Ydb.Export.ExportToS3Settings.StorageClass\x12\x11\n\tVerifySSL\x18\x08 \x01(\x08\x12\x11\n\tProxyHost\x18\t \x01(\t\x12\x11\n\tProxyPort\x18\n \x01(\r\x12\x39\n\x0bProxyScheme\x18\x0b \x01(\x0e\x32$.NKikimrSchemeOp.TS3Settings.EScheme\x12\x0e\n\x06Region\x18\x0c \x01(\t\x12\x34\n\x06Limits\x18\x64 \x01(\x0b\x32$.NKikimrSchemeOp.TS3Settings.TLimits\x12\x18\n\x10RequestTimeoutMs\x18\x65 \x01(\r\x12\x1c\n\x14HttpRequestTimeoutMs\x18\x66 \x01(\r\x12\x1b\n\x13\x43onnectionTimeoutMs\x18g \x01(\r\x1aS\n\x07TLimits\x12\x1e\n\rReadBatchSize\x18\x01 \x01(\r:\x07\x38\x33\x38\x38\x36\x30\x38\x12\"\n\x11MinWriteBatchSize\x18\x02 \x01(\r:\x07\x35\x32\x34\x32\x38\x38\x30J\x04\x08\x03\x10\x04\"\x1e\n\x07\x45Scheme\x12\x08\n\x04HTTP\x10\x00\x12\t\n\x05HTTPS\x10\x01\"h\n\x0cTTaskCleaner\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x35\n\x0fStorageSettings\x18\x02 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TS3Settings\x12\x11\n\tTieringId\x18\x03 \x01(\t\"\xb3\x04\n\x0bTBackupTask\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\x12\x10\n\x08ShardNum\x18\x03 \x01(\r\x12\x17\n\x0fNumberOfRetries\x18\x05 \x01(\r\x12\x32\n\nYTSettings\x18\x04 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TYTSettingsH\x00\x12\x32\n\nS3Settings\x18\t \x01(\x0b\x32\x1c.NKikimrSchemeOp.TS3SettingsH\x00\x12\x30\n\x05Table\x18\n \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12@\n\x0cScanSettings\x18\x0b \x01(\x0b\x32*.NKikimrSchemeOp.TBackupTask.TScanSettings\x12\x12\n\nNeedToBill\x18\x0c \x01(\x08\x12\x45\n\x0b\x43ompression\x18\r \x01(\x0b\x32\x30.NKikimrSchemeOp.TBackupTask.TCompressionOptions\x1aK\n\rTScanSettings\x12\x18\n\rRowsBatchSize\x18\x01 \x01(\x04:\x01\x30\x12 \n\x0e\x42ytesBatchSize\x18\x02 \x01(\x04:\x08\x33\x33\x35\x35\x34\x34\x33\x32\x1a\x33\n\x13TCompressionOptions\x12\r\n\x05\x43odec\x18\x01 \x01(\t\x12\r\n\x05Level\x18\x02 \x01(\x05\x42\n\n\x08SettingsJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"\xdb\x01\n\x0cTRestoreTask\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\x12<\n\x10TableDescription\x18\x03 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x10\n\x08ShardNum\x18\x04 \x01(\r\x12\x17\n\x0fNumberOfRetries\x18\x05 \x01(\r\x12\x32\n\nS3Settings\x18\x06 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TS3SettingsH\x00\x42\n\n\x08Settings\"\xbc\x03\n\x17TPersQueueGroupAllocate\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x14\n\x0c\x41lterVersion\x18\x02 \x01(\x04\x12\x17\n\x0fTotalGroupCount\x18\x03 \x01(\r\x12\x17\n\x0fNextPartitionId\x18\x04 \x01(\r\x12\x1a\n\x12PartitionPerTablet\x18\x05 \x01(\r\x12\x32\n\x0ePQTabletConfig\x18\x06 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12G\n\nPartitions\x18\x07 \x03(\x0b\x32\x33.NKikimrSchemeOp.TPersQueueGroupAllocate.TPartition\x12\x18\n\x10\x42\x61lancerTabletID\x18\x08 \x01(\x04\x12\x17\n\x0f\x42\x61lancerOwnerId\x18\t \x01(\x04\x12\x17\n\x0f\x42\x61lancerShardId\x18\n \x01(\x04\x1a\x66\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x0f\n\x07GroupId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12\x0f\n\x07OwnerId\x18\x04 \x01(\x04\x12\x0f\n\x07ShardId\x18\x05 \x01(\x04\")\n\x19TPersQueueGroupDeallocate\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\xf0\x05\n\x1aTPersQueueGroupDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x17\n\x0fTotalGroupCount\x18\x03 \x01(\r\x12T\n\x0fPartitionsToAdd\x18\t \x03(\x0b\x32;.NKikimrSchemeOp.TPersQueueGroupDescription.TPartitionToAdd\x12\x1a\n\x12PartitionsToDelete\x18\n \x03(\r\x12\x17\n\x0fNextPartitionId\x18\x0b \x01(\r\x12\x1a\n\x12PartitionPerTablet\x18\x04 \x01(\r\x12\x32\n\x0ePQTabletConfig\x18\x05 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12J\n\nPartitions\x18\x06 \x03(\x0b\x32\x36.NKikimrSchemeOp.TPersQueueGroupDescription.TPartition\x12\x14\n\x0c\x41lterVersion\x18\x07 \x01(\x04\x12\x18\n\x10\x42\x61lancerTabletID\x18\x08 \x01(\x04\x12\x33\n\x13PartitionBoundaries\x18\x0c \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12\x34\n\x0f\x42ootstrapConfig\x18\r \x01(\x0b\x32\x1b.NKikimrPQ.TBootstrapConfig\x12:\n\x08\x41llocate\x18\x0e \x01(\x0b\x32(.NKikimrSchemeOp.TPersQueueGroupAllocate\x1a\x64\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12/\n\x08KeyRange\x18\x03 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\x1a\x37\n\x0fTPartitionToAdd\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\"\xdc\x01\n\x16TRtmrVolumeDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x17\n\x0fPartitionsCount\x18\x03 \x01(\x04\x12\x46\n\nPartitions\x18\x04 \x03(\x0b\x32\x32.NKikimrSchemeOp.TRtmrVolumeDescription.TPartition\x1a\x43\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\x0c\x12\x0e\n\x06\x42usKey\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\"\xcf\x02\n\x1cTBlockStoreVolumeDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x36\n\x0cVolumeConfig\x18\x03 \x01(\x0b\x32 .NKikimrBlockStore.TVolumeConfig\x12L\n\nPartitions\x18\x04 \x03(\x0b\x32\x38.NKikimrSchemeOp.TBlockStoreVolumeDescription.TPartition\x12\x16\n\x0eVolumeTabletId\x18\x05 \x01(\x04\x12\x14\n\x0c\x41lterVersion\x18\x06 \x01(\x04\x12\x12\n\nMountToken\x18\x07 \x01(\t\x12\x14\n\x0cTokenVersion\x18\x08 \x01(\x04\x1a\x33\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"\x88\x01\n\x15TFileStoreDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rIndexTabletId\x18\x03 \x01(\x04\x12)\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x19.NKikimrFileStore.TConfig\x12\x0f\n\x07Version\x18\x05 \x01(\x04\"\x83\x01\n\x11TKesusDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rKesusTabletId\x18\x03 \x01(\x04\x12(\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x0f\n\x07Version\x18\x05 \x01(\x04\"\x9c\x02\n\x19TSolomonVolumeDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x16\n\x0ePartitionCount\x18\x03 \x01(\x04\x12I\n\nPartitions\x18\x04 \x03(\x0b\x32\x35.NKikimrSchemeOp.TSolomonVolumeDescription.TPartition\x1a~\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x10\n\x08ShardIdx\x18\x03 \x01(\x04\x12\x37\n\rBoundChannels\x18\x04 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\"\xf4\x01\n\x14TCreateSolomonVolume\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x18\n\x10\x43hannelProfileId\x18\x02 \x01(\r\x12\x16\n\x0ePartitionCount\x18\x03 \x01(\x04\x12R\n\x11\x41\x64optedPartitions\x18\x04 \x03(\x0b\x32\x37.NKikimrSchemeOp.TCreateSolomonVolume.TAdoptedPartition\x1aH\n\x11TAdoptedPartition\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x10\n\x08ShardIdx\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\"{\n\x13TAlterSolomonVolume\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x18\n\x10\x43hannelProfileId\x18\x02 \x01(\r\x12\x16\n\x0ePartitionCount\x18\x03 \x01(\x04\x12$\n\x15UpdateChannelsBinding\x18\x04 \x01(\x08:\x05\x66\x61lse\"P\n\x13TBlockStoreAssignOp\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\rNewMountToken\x18\x02 \x01(\t\x12\x14\n\x0cTokenVersion\x18\x03 \x01(\x04\"=\n\nTModifyACL\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x44iffACL\x18\x02 \x01(\x0c\x12\x10\n\x08NewOwner\x18\x03 \x01(\t\"\xd0\x01\n\x1aTSplitMergeTablePartitions\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x11\n\tTablePath\x18\x02 \x01(\t\x12\x14\n\x0cTableLocalId\x18\x03 \x01(\x04\x12\x16\n\x0eSourceTabletId\x18\x04 \x03(\x04\x12\x36\n\rSplitBoundary\x18\x05 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TSplitBoundary\x12\x15\n\rSchemeshardId\x18\x06 \x01(\x04\x12\x14\n\x0cTableOwnerId\x18\x07 \x01(\x04\",\n\x0eTUserAttribute\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"a\n\x14TAlterUserAttributes\x12\x10\n\x08PathName\x18\x01 \x01(\t\x12\x37\n\x0eUserAttributes\x18\x02 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\")\n\x05TMove\x12\x0f\n\x07SrcPath\x18\x01 \x01(\t\x12\x0f\n\x07\x44stPath\x18\x02 \x01(\t\"Y\n\nTMoveIndex\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12\x0f\n\x07SrcPath\x18\x02 \x01(\t\x12\x0f\n\x07\x44stPath\x18\x03 \x01(\t\x12\x16\n\x0e\x41llowOverwrite\x18\x04 \x01(\x08\"\xdc\x01\n\x14TSequenceDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12%\n\x06PathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x15\n\rSequenceShard\x18\x04 \x01(\x04\x12\x10\n\x08MinValue\x18\x05 \x01(\x12\x12\x10\n\x08MaxValue\x18\x06 \x01(\x12\x12\x12\n\nStartValue\x18\x07 \x01(\x12\x12\r\n\x05\x43\x61\x63he\x18\x08 \x01(\x04\x12\x11\n\tIncrement\x18\t \x01(\x12\x12\r\n\x05\x43ycle\x18\n \x01(\x08\"G\n\x11TSequenceSharding\x12\x32\n\x0eSequenceShards\x18\x01 \x03(\x0b\x32\x1a.NKikimrSchemeOp.TShardIdx\"\xad\x01\n\x17TReplicationDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x36\n\x06\x43onfig\x18\x02 \x01(\x0b\x32&.NKikimrReplication.TReplicationConfig\x12%\n\x06PathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07Version\x18\x04 \x01(\x04\x12\x14\n\x0c\x43ontrollerId\x18\x05 \x01(\x04\"\xa3\x01\n\x15TBlobDepotDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12%\n\x06PathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x32\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\".NKikimrBlobDepot.TBlobDepotConfig\x12\x10\n\x08TabletId\x18\x05 \x01(\x06\"C\n\x08TApplyIf\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x13\n\x0bPathVersion\x18\x02 \x01(\x04\x12\x12\n\nLockedTxId\x18\x03 \x01(\x04\"\x91\x01\n\x11TUpgradeSubDomain\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12>\n\x08\x44\x65\x63ision\x18\x02 \x01(\x0e\x32,.NKikimrSchemeOp.TUpgradeSubDomain.EDecision\".\n\tEDecision\x12\x0b\n\x07Invalid\x10\x00\x12\x08\n\x04Undo\x10\x02\x12\n\n\x06\x43ommit\x10\x03\"X\n\x11TIndexBuildConfig\x12\r\n\x05Table\x18\x01 \x01(\t\x12\x34\n\x05Index\x18\x02 \x01(\x0b\x32%.NKikimrSchemeOp.TIndexCreationConfig\"e\n\x12TIndexBuildControl\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12\x11\n\tIndexName\x18\x02 \x01(\t\x12\x13\n\x0bSnaphotTxId\x18\x03 \x01(\x04\x12\x14\n\x0c\x42uildIndexId\x18\x04 \x01(\x04\"\x1b\n\x0bTLockConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\x1f\n\nTLockGuard\x12\x11\n\tOwnerTxId\x18\x01 \x01(\x04\"2\n\nTDropIndex\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x11\n\tIndexName\x18\x02 \x01(\t\"\x8c\x1a\n\rTModifyScheme\x12\x12\n\nWorkingDir\x18\x01 \x01(\t\x12\x36\n\rOperationType\x18\x02 \x01(\x0e\x32\x1f.NKikimrSchemeOp.EOperationType\x12\x17\n\x08Internal\x18$ \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0b\x46\x61ilOnExist\x18\x32 \x01(\x08:\x05\x66\x61lse\x12(\n\x19\x41llowAccessToPrivatePaths\x18\x35 \x01(\x08:\x05\x66\x61lse\x12&\n\x05MkDir\x18\x03 \x01(\x0b\x32\x17.NKikimrSchemeOp.TMkDir\x12\x37\n\x0b\x43reateTable\x18\x04 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12I\n\x14\x43reatePersQueueGroup\x18\x05 \x01(\x0b\x32+.NKikimrSchemeOp.TPersQueueGroupDescription\x12H\n\x13\x41lterPersQueueGroup\x18\x06 \x01(\x0b\x32+.NKikimrSchemeOp.TPersQueueGroupDescription\x12$\n\x04\x44rop\x18\x07 \x01(\x0b\x32\x16.NKikimrSchemeOp.TDrop\x12.\n\tModifyACL\x18\x08 \x01(\x0b\x32\x1b.NKikimrSchemeOp.TModifyACL\x12\x36\n\nAlterTable\x18\t \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12N\n\x19SplitMergeTablePartitions\x18\n \x01(\x0b\x32+.NKikimrSchemeOp.TSplitMergeTablePartitions\x12,\n\x06\x42\x61\x63kup\x18\x0b \x01(\x0b\x32\x1c.NKikimrSchemeOp.TBackupTask\x12\x38\n\tSubDomain\x18\x0c \x01(\x0b\x32%.NKikimrSubDomains.TSubDomainSettings\x12\x41\n\x10\x43reateRtmrVolume\x18\r \x01(\x0b\x32\'.NKikimrSchemeOp.TRtmrVolumeDescription\x12M\n\x16\x43reateBlockStoreVolume\x18\x0e \x01(\x0b\x32-.NKikimrSchemeOp.TBlockStoreVolumeDescription\x12L\n\x15\x41lterBlockStoreVolume\x18\x0f \x01(\x0b\x32-.NKikimrSchemeOp.TBlockStoreVolumeDescription\x12\x44\n\x16\x41ssignBlockStoreVolume\x18\x10 \x01(\x0b\x32$.NKikimrSchemeOp.TBlockStoreAssignOp\x12\x31\n\x05Kesus\x18\x11 \x01(\x0b\x32\".NKikimrSchemeOp.TKesusDescription\x12\x42\n\x13\x43reateSolomonVolume\x18\x12 \x01(\x0b\x32%.NKikimrSchemeOp.TCreateSolomonVolume\x12\x42\n\x13\x41lterUserAttributes\x18\x13 \x01(\x0b\x32%.NKikimrSchemeOp.TAlterUserAttributes\x12*\n\x07\x41pplyIf\x18\x14 \x03(\x0b\x32\x19.NKikimrSchemeOp.TApplyIf\x12?\n\x10\x43reateTableIndex\x18\x15 \x01(\x0b\x32%.NKikimrSchemeOp.TIndexCreationConfig\x12H\n\x12\x43reateIndexedTable\x18\x16 \x01(\x0b\x32,.NKikimrSchemeOp.TIndexedTableCreationConfig\x12R\n\x1a\x43reateConsistentCopyTables\x18\x17 \x01(\x0b\x32..NKikimrSchemeOp.TConsistentTableCopyingConfig\x12<\n\x10UpgradeSubDomain\x18\x19 \x01(\x0b\x32\".NKikimrSchemeOp.TUpgradeSubDomain\x12>\n\x12InitiateIndexBuild\x18\x1a \x01(\x0b\x32\".NKikimrSchemeOp.TIndexBuildConfig\x12R\n\x1bInitiateBuildIndexMainTable\x18\x1b \x01(\x0b\x32-.NKikimrSchemeOp.TInitiateBuildIndexMainTable\x12\x30\n\nLockConfig\x18\x1c \x01(\x0b\x32\x1c.NKikimrSchemeOp.TLockConfig\x12.\n\tLockGuard\x18\x1d \x01(\x0b\x32\x1b.NKikimrSchemeOp.TLockGuard\x12>\n\x0f\x41lterTableIndex\x18\x1e \x01(\x0b\x32%.NKikimrSchemeOp.TIndexAlteringConfig\x12R\n\x1b\x46inalizeBuildIndexMainTable\x18\x1f \x01(\x0b\x32-.NKikimrSchemeOp.TFinalizeBuildIndexMainTable\x12<\n\x0f\x41pplyIndexBuild\x18  \x01(\x0b\x32#.NKikimrSchemeOp.TIndexBuildControl\x12@\n\x12\x41lterSolomonVolume\x18! \x01(\x0b\x32$.NKikimrSchemeOp.TAlterSolomonVolume\x12.\n\tDropIndex\x18\" \x01(\x0b\x32\x1b.NKikimrSchemeOp.TDropIndex\x12=\n\x10\x43\x61ncelIndexBuild\x18# \x01(\x0b\x32#.NKikimrSchemeOp.TIndexBuildControl\x12?\n\x0f\x43reateFileStore\x18% \x01(\x0b\x32&.NKikimrSchemeOp.TFileStoreDescription\x12>\n\x0e\x41lterFileStore\x18& \x01(\x0b\x32&.NKikimrSchemeOp.TFileStoreDescription\x12.\n\x07Restore\x18\' \x01(\x0b\x32\x1d.NKikimrSchemeOp.TRestoreTask\x12\x43\n\x11\x43reateColumnStore\x18( \x01(\x0b\x32(.NKikimrSchemeOp.TColumnStoreDescription\x12\x43\n\x11\x43reateColumnTable\x18) \x01(\x0b\x32(.NKikimrSchemeOp.TColumnTableDescription\x12<\n\x10\x41lterColumnStore\x18* \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnStore\x12<\n\x10\x41lterColumnTable\x18+ \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnTable\x12\x30\n\nAlterLogin\x18, \x01(\x0b\x32\x1c.NKikimrSchemeOp.TAlterLogin\x12:\n\x0f\x43reateCdcStream\x18- \x01(\x0b\x32!.NKikimrSchemeOp.TCreateCdcStream\x12\x38\n\x0e\x41lterCdcStream\x18. \x01(\x0b\x32 .NKikimrSchemeOp.TAlterCdcStream\x12\x36\n\rDropCdcStream\x18/ \x01(\x0b\x32\x1f.NKikimrSchemeOp.TDropCdcStream\x12)\n\tMoveTable\x18\x30 \x01(\x0b\x32\x16.NKikimrSchemeOp.TMove\x12.\n\x0eMoveTableIndex\x18\x31 \x01(\x0b\x32\x16.NKikimrSchemeOp.TMove\x12\x37\n\x08Sequence\x18\x33 \x01(\x0b\x32%.NKikimrSchemeOp.TSequenceDescription\x12=\n\x0bReplication\x18\x34 \x01(\x0b\x32(.NKikimrSchemeOp.TReplicationDescription\x12\x39\n\tBlobDepot\x18\x36 \x01(\x0b\x32&.NKikimrSchemeOp.TBlobDepotDescription\x12.\n\tMoveIndex\x18\x37 \x01(\x0b\x32\x1b.NKikimrSchemeOp.TMoveIndex\x12H\n\x16\x41llocatePersQueueGroup\x18\x38 \x01(\x0b\x32(.NKikimrSchemeOp.TPersQueueGroupAllocate\x12L\n\x18\x44\x65\x61llocatePersQueueGroup\x18\x39 \x01(\x0b\x32*.NKikimrSchemeOp.TPersQueueGroupDeallocateJ\x04\x08\x18\x10\x19\"E\n\rTModifyScript\x12\x34\n\x0cModifyScheme\x18\x01 \x03(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\"\xc1\x02\n\x10TDescribeOptions\x12$\n\x16ReturnPartitioningInfo\x18\x01 \x01(\x08:\x04true\x12#\n\x15ReturnPartitionConfig\x18\x02 \x01(\x08:\x04true\x12\x19\n\nBackupInfo\x18\x03 \x01(\x08:\x05\x66\x61lse\x12#\n\x14ReturnPartitionStats\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x0eReturnChildren\x18\x05 \x01(\x08:\x04true\x12\x1f\n\x10ReturnBoundaries\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10ShowPrivateTable\x18\x07 \x01(\x08:\x05\x66\x61lse\x12$\n\x15ReturnChannelsBinding\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x0eReturnRangeKey\x18\t \x01(\x08:\x04true\"\xde\x01\n\rTDescribePath\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rSchemeshardId\x18\x03 \x01(\x04\x12$\n\x16ReturnPartitioningInfo\x18\x04 \x01(\x08:\x04true\x12#\n\x15ReturnPartitionConfig\x18\x05 \x01(\x08:\x04true\x12\x19\n\nBackupInfo\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x32\n\x07Options\x18\x07 \x01(\x0b\x32!.NKikimrSchemeOp.TDescribeOptions\"\xc9\x05\n\x0cTPathVersion\x12\x16\n\x0eGeneralVersion\x18\x01 \x01(\x04\x12\x12\n\nACLVersion\x18\x02 \x01(\x04\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x03 \x01(\x04\x12\x18\n\x10UserAttrsVersion\x18\x04 \x01(\x04\x12\x17\n\x0f\x43hildrenVersion\x18\x05 \x01(\x04\x12\x18\n\x10SubDomainVersion\x18\x06 \x01(\x04\x12\x1a\n\x12TableSchemaVersion\x18\x07 \x01(\x04\x12\x1d\n\x15TablePartitionVersion\x18\x08 \x01(\x04\x12\x19\n\x11TableIndexVersion\x18\t \x01(\x04\x12\x11\n\tPQVersion\x18\n \x01(\x04\x12\x12\n\nBSVVersion\x18\x0b \x01(\x04\x12\x14\n\x0cKesusVersion\x18\x0c \x01(\x04\x12\x13\n\x0bRTMRVersion\x18\r \x01(\x04\x12\x16\n\x0eSolomonVersion\x18\x0e \x01(\x04\x12\x18\n\x10\x46ileStoreVersion\x18\x0f \x01(\x04\x12\x1a\n\x12\x43olumnStoreVersion\x18\x10 \x01(\x04\x12\x1a\n\x12\x43olumnTableVersion\x18\x11 \x01(\x04\x12\"\n\x1a\x43olumnTableShardingVersion\x18\x12 \x01(\x04\x12\x1d\n\x15SubDomainStateVersion\x18\x13 \x01(\x04\x12 \n\x18\x43olumnTableSchemaVersion\x18\x14 \x01(\x04\x12%\n\x1d\x43olumnTableTtlSettingsVersion\x18\x15 \x01(\x04\x12\x18\n\x10\x43\x64\x63StreamVersion\x18\x16 \x01(\x04\x12\x1c\n\x14SecurityStateVersion\x18\x17 \x01(\x04\x12\x17\n\x0fSequenceVersion\x18\x18 \x01(\x04\x12\x1a\n\x12ReplicationVersion\x18\x19 \x01(\x04\x12\x18\n\x10\x42lobDepotVersion\x18\x1a \x01(\x04\"\xba\x03\n\tTDirEntry\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rSchemeshardId\x18\x03 \x01(\x04\x12,\n\x08PathType\x18\x04 \x01(\x0e\x32\x1a.NKikimrSchemeOp.EPathType\x12\x16\n\x0e\x43reateFinished\x18\x05 \x01(\x08\x12\x12\n\nCreateTxId\x18\x06 \x01(\x04\x12\x12\n\nCreateStep\x18\x07 \x01(\x04\x12\x14\n\x0cParentPathId\x18\x08 \x01(\x04\x12.\n\tPathState\x18\t \x01(\x0e\x32\x1b.NKikimrSchemeOp.EPathState\x12\r\n\x05Owner\x18\n \x01(\t\x12\x0b\n\x03\x41\x43L\x18\x0b \x01(\x0c\x12\x14\n\x0c\x45\x66\x66\x65\x63tiveACL\x18\x0c \x01(\x0c\x12\x13\n\x0bPathVersion\x18\r \x01(\x04\x12\x32\n\x0bPathSubType\x18\x0e \x01(\x0e\x32\x1d.NKikimrSchemeOp.EPathSubType\x12.\n\x07Version\x18\x0f \x01(\x0b\x32\x1d.NKikimrSchemeOp.TPathVersion\x12\x19\n\x10\x42\x61lancerTabletID\x18\xe7\x07 \x01(\x04\"i\n\x0fTTablePartition\x12\x1b\n\x13\x45ndOfRangeKeyPrefix\x18\x01 \x01(\x0c\x12\x0f\n\x07IsPoint\x18\x02 \x01(\x08\x12\x13\n\x0bIsInclusive\x18\x03 \x01(\x08\x12\x13\n\x0b\x44\x61tashardId\x18\x04 \x01(\x04\"/\n\x0bTShardError\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x0f\n\x07\x45xplain\x18\x02 \x01(\t\"\xe4\x01\n\x0fTBackupProgress\x12\x16\n\x0eNotCompleteYet\x18\x01 \x01(\r\x12\r\n\x05Total\x18\x02 \x01(\r\x12\x12\n\nErrorCount\x18\x03 \x01(\r\x12\x11\n\tStartTime\x18\x04 \x01(\x04\x12,\n\x06\x45rrors\x18\x05 \x03(\x0b\x32\x1c.NKikimrSchemeOp.TShardError\x12\x30\n\nYTSettings\x18\x06 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TYTSettings\x12\x15\n\rDataTotalSize\x18\x07 \x01(\x04\x12\x0c\n\x04TxId\x18\x08 \x01(\x04\"\xdf\x01\n\x11TLastBackupResult\x12\x12\n\nErrorCount\x18\x01 \x01(\r\x12\x19\n\x11\x43ompleteTimeStamp\x18\x02 \x01(\x04\x12\x16\n\x0eStartTimeStamp\x18\x03 \x01(\x04\x12,\n\x06\x45rrors\x18\x04 \x03(\x0b\x32\x1c.NKikimrSchemeOp.TShardError\x12\x30\n\nYTSettings\x18\x05 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TYTSettings\x12\x15\n\rDataTotalSize\x18\x06 \x01(\x04\x12\x0c\n\x04TxId\x18\x07 \x01(\x04\"\xda\x0c\n\x10TPathDescription\x12(\n\x04Self\x18\x01 \x01(\x0b\x32\x1a.NKikimrSchemeOp.TDirEntry\x12,\n\x08\x43hildren\x18\x02 \x03(\x0b\x32\x1a.NKikimrSchemeOp.TDirEntry\x12\x31\n\x05Table\x18\x03 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x39\n\x0fTablePartitions\x18\x04 \x03(\x0b\x32 .NKikimrSchemeOp.TTablePartition\x12\x43\n\x0ePersQueueGroup\x18\x05 \x01(\x0b\x32+.NKikimrSchemeOp.TPersQueueGroupDescription\x12\x38\n\x0e\x42\x61\x63kupProgress\x18\x06 \x01(\x0b\x32 .NKikimrSchemeOp.TBackupProgress\x12<\n\x10LastBackupResult\x18\x07 \x03(\x0b\x32\".NKikimrSchemeOp.TLastBackupResult\x12\x32\n\nTableStats\x18\x08 \x01(\x0b\x32\x1e.NKikimrTableStats.TTableStats\x12\x32\n\rTabletMetrics\x18\t \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12@\n\x11\x44omainDescription\x18\n \x01(\x0b\x32%.NKikimrSubDomains.TDomainDescription\x12\x46\n\x15RtmrVolumeDescription\x18\x0b \x01(\x0b\x32\'.NKikimrSchemeOp.TRtmrVolumeDescription\x12R\n\x1b\x42lockStoreVolumeDescription\x18\x0c \x01(\x0b\x32-.NKikimrSchemeOp.TBlockStoreVolumeDescription\x12\x31\n\x05Kesus\x18\r \x01(\x0b\x32\".NKikimrSchemeOp.TKesusDescription\x12\x46\n\x12SolomonDescription\x18\x0e \x01(\x0b\x32*.NKikimrSchemeOp.TSolomonVolumeDescription\x12;\n\x13TablePartitionStats\x18\x0f \x03(\x0b\x32\x1e.NKikimrTableStats.TTableStats\x12\x37\n\x0eUserAttributes\x18\x10 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12\x36\n\nTableIndex\x18\x11 \x01(\x0b\x32\".NKikimrSchemeOp.TIndexDescription\x12:\n\x15TablePartitionMetrics\x18\x12 \x03(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12$\n\x1c\x41\x62\x61ndonedTenantsSchemeShards\x18\x13 \x03(\x04\x12\x44\n\x14\x46ileStoreDescription\x18\x14 \x01(\x0b\x32&.NKikimrSchemeOp.TFileStoreDescription\x12H\n\x16\x43olumnStoreDescription\x18\x15 \x01(\x0b\x32(.NKikimrSchemeOp.TColumnStoreDescription\x12H\n\x16\x43olumnTableDescription\x18\x16 \x01(\x0b\x32(.NKikimrSchemeOp.TColumnTableDescription\x12\x44\n\x14\x43\x64\x63StreamDescription\x18\x17 \x01(\x0b\x32&.NKikimrSchemeOp.TCdcStreamDescription\x12\x42\n\x13SequenceDescription\x18\x18 \x01(\x0b\x32%.NKikimrSchemeOp.TSequenceDescription\x12H\n\x16ReplicationDescription\x18\x19 \x01(\x0b\x32(.NKikimrSchemeOp.TReplicationDescription\x12\x44\n\x14\x42lobDepotDescription\x18\x1a \x01(\x0b\x32&.NKikimrSchemeOp.TBlobDepotDescription\"M\n\x0fTAlterExtraData\x12:\n\x0fPartitionConfig\x18\x01 \x01(\x0b\x32!.NKikimrSchemeOp.TPartitionConfig\"\xda\x03\n\x10TResourceProfile\x12\x42\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType:\x07Unknown\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12)\n\x18\x44\x65\x66\x61ultTabletMemoryUsage\x18\x03 \x01(\x04:\x07\x31\x30\x34\x38\x35\x37\x36\x12$\n\x19StaticTabletTxMemoryLimit\x18\x04 \x01(\x04:\x01\x30\x12&\n\x13StaticTxMemoryLimit\x18\x05 \x01(\x04:\t262144000\x12\x18\n\rTxMemoryLimit\x18\x06 \x01(\x04:\x01\x30\x12 \n\x0fInitialTxMemory\x18\x07 \x01(\x04:\x07\x34\x31\x39\x34\x33\x30\x34\x12$\n\x12SmallTxMemoryLimit\x18\x08 \x01(\x04:\x08\x31\x30\x34\x38\x35\x37\x36\x30\x12&\n\x13MediumTxMemoryLimit\x18\t \x01(\x04:\t104857600\x12$\n\x0fSmallTxTaskType\x18\n \x01(\t:\x0btransaction\x12%\n\x10MediumTxTaskType\x18\x0b \x01(\t:\x0btransaction\x12$\n\x0fLargeTxTaskType\x18\x0c \x01(\t:\x0btransaction*V\n\x0f\x45\x44ropWaitPolicy\x12\x16\n\x12\x45\x44ropFailOnChanges\x10\x00\x12\x15\n\x11\x45\x44ropAbortChanges\x10\x01\x12\x14\n\x10\x45\x44ropWaitChanges\x10\x02*M\n\x0c\x45\x43olumnCodec\x12\x14\n\x10\x43olumnCodecPlain\x10\x00\x12\x12\n\x0e\x43olumnCodecLZ4\x10\x01\x12\x13\n\x0f\x43olumnCodecZSTD\x10\x02*M\n\x0c\x45\x43olumnCache\x12\x13\n\x0f\x43olumnCacheNone\x10\x00\x12\x13\n\x0f\x43olumnCacheOnce\x10\x01\x12\x13\n\x0f\x43olumnCacheEver\x10\x02*\xef\x01\n\x0e\x45\x43olumnStorage\x12\x12\n\x0e\x43olumnStorage1\x10\x00\x12\x12\n\x0e\x43olumnStorage2\x10\x01\x12\x16\n\x12\x43olumnStorage1Ext1\x10\x02\x12\x16\n\x12\x43olumnStorage1Ext2\x10\x03\x12\x16\n\x12\x43olumnStorage2Ext1\x10\x04\x12\x16\n\x12\x43olumnStorage2Ext2\x10\x05\x12\x1a\n\x16\x43olumnStorage1Med2Ext2\x10\x06\x12\x1a\n\x16\x43olumnStorage2Med2Ext2\x10\x07\x12\x1d\n\x18\x43olumnStorageTest_1_2_1k\x10\xe7\x07*9\n\x0c\x45\x46reezeState\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x46reeze\x10\x01\x12\x0c\n\x08Unfreeze\x10\x02*D\n\nEMvccState\x12\x13\n\x0fMvccUnspecified\x10\x00\x12\x0f\n\x0bMvccEnabled\x10\x01\x12\x10\n\x0cMvccDisabled\x10\x02*u\n\x13\x45\x43ompactionStrategy\x12\x1b\n\x17\x43ompactionStrategyUnset\x10\x00\x12\"\n\x1e\x43ompactionStrategyGenerational\x10\x01\x12\x1d\n\x19\x43ompactionStrategySharded\x10\x02*T\n\x12\x45\x43olumnTableEngine\x12\x16\n\x12\x43OLUMN_ENGINE_NONE\x10\x00\x12&\n\"COLUMN_ENGINE_REPLACING_TIMESERIES\x10\x01*^\n\x10\x45OlapProgramType\x12\x1c\n\x18OLAP_PROGRAM_SSA_PROGRAM\x10\x01\x12,\n(OLAP_PROGRAM_SSA_PROGRAM_WITH_PARAMETERS\x10\x02*}\n\x0f\x45\x43\x64\x63StreamState\x12\x1a\n\x16\x45\x43\x64\x63StreamStateInvalid\x10\x00\x12\x18\n\x14\x45\x43\x64\x63StreamStateReady\x10\x01\x12\x1b\n\x17\x45\x43\x64\x63StreamStateDisabled\x10\x02\x12\x17\n\x13\x45\x43\x64\x63StreamStateScan\x10\x03*\xbc\x01\n\x0e\x45\x43\x64\x63StreamMode\x12\x19\n\x15\x45\x43\x64\x63StreamModeInvalid\x10\x00\x12\x1a\n\x16\x45\x43\x64\x63StreamModeKeysOnly\x10\x01\x12\x18\n\x14\x45\x43\x64\x63StreamModeUpdate\x10\x02\x12\x1a\n\x16\x45\x43\x64\x63StreamModeNewImage\x10\x03\x12\x1a\n\x16\x45\x43\x64\x63StreamModeOldImage\x10\x04\x12!\n\x1d\x45\x43\x64\x63StreamModeNewAndOldImages\x10\x05*d\n\x10\x45\x43\x64\x63StreamFormat\x12\x1b\n\x17\x45\x43\x64\x63StreamFormatInvalid\x10\x00\x12\x19\n\x15\x45\x43\x64\x63StreamFormatProto\x10\x01\x12\x18\n\x14\x45\x43\x64\x63StreamFormatJson\x10\x02*T\n\nEIndexType\x12\x15\n\x11\x45IndexTypeInvalid\x10\x00\x12\x14\n\x10\x45IndexTypeGlobal\x10\x01\x12\x19\n\x15\x45IndexTypeGlobalAsync\x10\x02*n\n\x0b\x45IndexState\x12\x16\n\x12\x45IndexStateInvalid\x10\x00\x12\x14\n\x10\x45IndexStateReady\x10\x01\x12\x17\n\x13\x45IndexStateNotReady\x10\x02\x12\x18\n\x14\x45IndexStateWriteOnly\x10\x03*\xe5\x14\n\x0e\x45OperationType\x12\x12\n\x0e\x45SchemeOpMkDir\x10\x01\x12\x18\n\x14\x45SchemeOpCreateTable\x10\x02\x12!\n\x1d\x45SchemeOpCreatePersQueueGroup\x10\x03\x12\x16\n\x12\x45SchemeOpDropTable\x10\x04\x12\x1f\n\x1b\x45SchemeOpDropPersQueueGroup\x10\x05\x12\x17\n\x13\x45SchemeOpAlterTable\x10\x06\x12 \n\x1c\x45SchemeOpAlterPersQueueGroup\x10\x07\x12\x16\n\x12\x45SchemeOpModifyACL\x10\x08\x12\x12\n\x0e\x45SchemeOpRmDir\x10\t\x12&\n\"ESchemeOpSplitMergeTablePartitions\x10\n\x12\x13\n\x0f\x45SchemeOpBackup\x10\x0b\x12\x1c\n\x18\x45SchemeOpCreateSubDomain\x10\x0c\x12\x1a\n\x16\x45SchemeOpDropSubDomain\x10\r\x12\x1d\n\x19\x45SchemeOpCreateRtmrVolume\x10\x0e\x12#\n\x1f\x45SchemeOpCreateBlockStoreVolume\x10\x0f\x12\"\n\x1e\x45SchemeOpAlterBlockStoreVolume\x10\x10\x12#\n\x1f\x45SchemeOpAssignBlockStoreVolume\x10\x11\x12!\n\x1d\x45SchemeOpDropBlockStoreVolume\x10\x12\x12\x18\n\x14\x45SchemeOpCreateKesus\x10\x13\x12\x16\n\x12\x45SchemeOpDropKesus\x10\x14\x12\x1f\n\x1b\x45SchemeOpForceDropSubDomain\x10\x15\x12 \n\x1c\x45SchemeOpCreateSolomonVolume\x10\x16\x12\x1e\n\x1a\x45SchemeOpDropSolomonVolume\x10\x17\x12\x17\n\x13\x45SchemeOpAlterKesus\x10\x18\x12\x1b\n\x17\x45SchemeOpAlterSubDomain\x10\x19\x12 \n\x1c\x45SchemeOpAlterUserAttributes\x10\x1a\x12\x1c\n\x18\x45SchemeOpForceDropUnsafe\x10\x1b\x12\x1f\n\x1b\x45SchemeOpCreateIndexedTable\x10\x1c\x12\x1d\n\x19\x45SchemeOpCreateTableIndex\x10\x1d\x12\'\n#ESchemeOpCreateConsistentCopyTables\x10\x1e\x12\x1b\n\x17\x45SchemeOpDropTableIndex\x10\x1f\x12\x1f\n\x1b\x45SchemeOpCreateExtSubDomain\x10 \x12\x1e\n\x1a\x45SchemeOpAlterExtSubDomain\x10!\x12\"\n\x1e\x45SchemeOpForceDropExtSubDomain\x10\"\x12\x1b\n\x17\x45SchemeOp_DEPRECATED_35\x10#\x12\x1d\n\x19\x45SchemeOpUpgradeSubDomain\x10$\x12%\n!ESchemeOpUpgradeSubDomainDecision\x10%\x12\x1d\n\x19\x45SchemeOpCreateIndexBuild\x10&\x12(\n$ESchemeOpInitiateBuildIndexMainTable\x10\'\x12\x17\n\x13\x45SchemeOpCreateLock\x10(\x12\x1c\n\x18\x45SchemeOpApplyIndexBuild\x10)\x12(\n$ESchemeOpFinalizeBuildIndexMainTable\x10*\x12\x1c\n\x18\x45SchemeOpAlterTableIndex\x10+\x12\x1f\n\x1b\x45SchemeOpAlterSolomonVolume\x10,\x12\x15\n\x11\x45SchemeOpDropLock\x10-\x12(\n$ESchemeOpFinalizeBuildIndexImplTable\x10.\x12(\n$ESchemeOpInitiateBuildIndexImplTable\x10/\x12\x16\n\x12\x45SchemeOpDropIndex\x10\x30\x12&\n\"ESchemeOpDropTableIndexAtMainTable\x10\x31\x12\x1d\n\x19\x45SchemeOpCancelIndexBuild\x10\x32\x12\x1c\n\x18\x45SchemeOpCreateFileStore\x10\x33\x12\x1b\n\x17\x45SchemeOpAlterFileStore\x10\x34\x12\x1a\n\x16\x45SchemeOpDropFileStore\x10\x35\x12\x14\n\x10\x45SchemeOpRestore\x10\x36\x12\x1e\n\x1a\x45SchemeOpCreateColumnStore\x10\x37\x12\x1d\n\x19\x45SchemeOpAlterColumnStore\x10\x38\x12\x1c\n\x18\x45SchemeOpDropColumnStore\x10\x39\x12\x1e\n\x1a\x45SchemeOpCreateColumnTable\x10:\x12\x1d\n\x19\x45SchemeOpAlterColumnTable\x10;\x12\x1c\n\x18\x45SchemeOpDropColumnTable\x10<\x12\x17\n\x13\x45SchemeOpAlterLogin\x10=\x12\x1c\n\x18\x45SchemeOpCreateCdcStream\x10>\x12 \n\x1c\x45SchemeOpCreateCdcStreamImpl\x10?\x12#\n\x1f\x45SchemeOpCreateCdcStreamAtTable\x10@\x12\x1b\n\x17\x45SchemeOpAlterCdcStream\x10\x41\x12\x1f\n\x1b\x45SchemeOpAlterCdcStreamImpl\x10\x42\x12\"\n\x1e\x45SchemeOpAlterCdcStreamAtTable\x10\x43\x12\x1a\n\x16\x45SchemeOpDropCdcStream\x10\x44\x12\x1e\n\x1a\x45SchemeOpDropCdcStreamImpl\x10\x45\x12!\n\x1d\x45SchemeOpDropCdcStreamAtTable\x10\x46\x12\x16\n\x12\x45SchemeOpMoveTable\x10G\x12\x1b\n\x17\x45SchemeOpMoveTableIndex\x10H\x12\x1b\n\x17\x45SchemeOpCreateSequence\x10I\x12\x1a\n\x16\x45SchemeOpAlterSequence\x10J\x12\x19\n\x15\x45SchemeOpDropSequence\x10K\x12\x1e\n\x1a\x45SchemeOpCreateReplication\x10L\x12\x1d\n\x19\x45SchemeOpAlterReplication\x10M\x12\x1c\n\x18\x45SchemeOpDropReplication\x10N\x12\x1c\n\x18\x45SchemeOpCreateBlobDepot\x10O\x12\x1b\n\x17\x45SchemeOpAlterBlobDepot\x10P\x12\x1a\n\x16\x45SchemeOpDropBlobDepot\x10Q\x12\x16\n\x12\x45SchemeOpMoveIndex\x10R\x12#\n\x1f\x45SchemeOpAllocatePersQueueGroup\x10S\x12%\n!ESchemeOpDeallocatePersQueueGroup\x10T\x12(\n$ESchemeOpAlterExtSubDomainCreateHive\x10U*\xc5\x03\n\tEPathType\x12\x14\n\x10\x45PathTypeInvalid\x10\x00\x12\x10\n\x0c\x45PathTypeDir\x10\x01\x12\x12\n\x0e\x45PathTypeTable\x10\x02\x12\x1b\n\x17\x45PathTypePersQueueGroup\x10\x03\x12\x16\n\x12\x45PathTypeSubDomain\x10\x04\x12\x17\n\x13\x45PathTypeRtmrVolume\x10\x05\x12\x1d\n\x19\x45PathTypeBlockStoreVolume\x10\x06\x12\x12\n\x0e\x45PathTypeKesus\x10\x07\x12\x1a\n\x16\x45PathTypeSolomonVolume\x10\x08\x12\x17\n\x13\x45PathTypeTableIndex\x10\t\x12\x19\n\x15\x45PathTypeExtSubDomain\x10\n\x12\x16\n\x12\x45PathTypeFileStore\x10\x0b\x12\x18\n\x14\x45PathTypeColumnStore\x10\x0c\x12\x18\n\x14\x45PathTypeColumnTable\x10\r\x12\x16\n\x12\x45PathTypeCdcStream\x10\x0e\x12\x15\n\x11\x45PathTypeSequence\x10\x0f\x12\x18\n\x14\x45PathTypeReplication\x10\x10\x12\x16\n\x12\x45PathTypeBlobDepot\x10\x11*\x8a\x01\n\x0c\x45PathSubType\x12\x15\n\x11\x45PathSubTypeEmpty\x10\x00\x12\"\n\x1e\x45PathSubTypeSyncIndexImplTable\x10\x01\x12#\n\x1f\x45PathSubTypeAsyncIndexImplTable\x10\x02\x12\x1a\n\x16\x45PathSubTypeStreamImpl\x10\x03*\x85\x02\n\nEPathState\x12\x16\n\x12\x45PathStateNotExist\x10\x01\x12\x17\n\x13\x45PathStateNoChanges\x10\x02\x12\x14\n\x10\x45PathStateCreate\x10\x03\x12\x13\n\x0f\x45PathStateAlter\x10\x04\x12\x12\n\x0e\x45PathStateDrop\x10\x05\x12\x15\n\x11\x45PathStateCopying\x10\x06\x12\x14\n\x10\x45PathStateBackup\x10\x07\x12\x15\n\x11\x45PathStateUpgrade\x10\x08\x12\x16\n\x12\x45PathStateMigrated\x10\t\x12\x15\n\x11\x45PathStateRestore\x10\n\x12\x14\n\x10\x45PathStateMoving\x10\x0b\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.flat_scheme_op_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EDROPWAITPOLICY._serialized_start=28413
  _EDROPWAITPOLICY._serialized_end=28499
  _ECOLUMNCODEC._serialized_start=28501
  _ECOLUMNCODEC._serialized_end=28578
  _ECOLUMNCACHE._serialized_start=28580
  _ECOLUMNCACHE._serialized_end=28657
  _ECOLUMNSTORAGE._serialized_start=28660
  _ECOLUMNSTORAGE._serialized_end=28899
  _EFREEZESTATE._serialized_start=28901
  _EFREEZESTATE._serialized_end=28958
  _EMVCCSTATE._serialized_start=28960
  _EMVCCSTATE._serialized_end=29028
  _ECOMPACTIONSTRATEGY._serialized_start=29030
  _ECOMPACTIONSTRATEGY._serialized_end=29147
  _ECOLUMNTABLEENGINE._serialized_start=29149
  _ECOLUMNTABLEENGINE._serialized_end=29233
  _EOLAPPROGRAMTYPE._serialized_start=29235
  _EOLAPPROGRAMTYPE._serialized_end=29329
  _ECDCSTREAMSTATE._serialized_start=29331
  _ECDCSTREAMSTATE._serialized_end=29456
  _ECDCSTREAMMODE._serialized_start=29459
  _ECDCSTREAMMODE._serialized_end=29647
  _ECDCSTREAMFORMAT._serialized_start=29649
  _ECDCSTREAMFORMAT._serialized_end=29749
  _EINDEXTYPE._serialized_start=29751
  _EINDEXTYPE._serialized_end=29835
  _EINDEXSTATE._serialized_start=29837
  _EINDEXSTATE._serialized_end=29947
  _EOPERATIONTYPE._serialized_start=29950
  _EOPERATIONTYPE._serialized_end=32611
  _EPATHTYPE._serialized_start=32614
  _EPATHTYPE._serialized_end=33067
  _EPATHSUBTYPE._serialized_start=33070
  _EPATHSUBTYPE._serialized_end=33208
  _EPATHSTATE._serialized_start=33211
  _EPATHSTATE._serialized_end=33472
  _TMKDIR._serialized_start=692
  _TMKDIR._serialized_end=714
  _TDROP._serialized_start=716
  _TDROP._serialized_end=803
  _TCOLUMNDESCRIPTION._serialized_start=806
  _TCOLUMNDESCRIPTION._serialized_end=1025
  _TSTORAGESETTINGS._serialized_start=1027
  _TSTORAGESETTINGS._serialized_end=1103
  _TSTORAGECONFIG._serialized_start=1106
  _TSTORAGECONFIG._serialized_end=1373
  _TFAMILYDESCRIPTION._serialized_start=1376
  _TFAMILYDESCRIPTION._serialized_end=1679
  _TCOMPACTIONPOLICY._serialized_start=1682
  _TCOMPACTIONPOLICY._serialized_end=3758
  _TCOMPACTIONPOLICY_TBACKGROUNDPOLICY._serialized_start=2632
  _TCOMPACTIONPOLICY_TBACKGROUNDPOLICY._serialized_end=2774
  _TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_start=2777
  _TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_end=3250
  _TCOMPACTIONPOLICY_TSHARDPOLICY._serialized_start=3253
  _TCOMPACTIONPOLICY_TSHARDPOLICY._serialized_end=3758
  _TFASTSPLITSETTINGS._serialized_start=3760
  _TFASTSPLITSETTINGS._serialized_end=3862
  _TSPLITBYLOADSETTINGS._serialized_start=3864
  _TSPLITBYLOADSETTINGS._serialized_end=3935
  _TPARTITIONINGPOLICY._serialized_start=3938
  _TPARTITIONINGPOLICY._serialized_end=4168
  _TPIPELINECONFIG._serialized_start=4171
  _TPIPELINECONFIG._serialized_end=4322
  _TPARTITIONCONFIG._serialized_start=4325
  _TPARTITIONCONFIG._serialized_end=5239
  _TSPLITBOUNDARY._serialized_start=5241
  _TSPLITBOUNDARY._serialized_end=5329
  _TSHARDIDX._serialized_start=5331
  _TSHARDIDX._serialized_end=5376
  _TTTLSETTINGS._serialized_start=5379
  _TTTLSETTINGS._serialized_end=6046
  _TTTLSETTINGS_TSYSSETTINGS._serialized_start=5536
  _TTTLSETTINGS_TSYSSETTINGS._serialized_end=5730
  _TTTLSETTINGS_TENABLED._serialized_start=5733
  _TTTLSETTINGS_TENABLED._serialized_end=5913
  _TTTLSETTINGS_TDISABLED._serialized_start=5915
  _TTTLSETTINGS_TDISABLED._serialized_end=5926
  _TTTLSETTINGS_EUNIT._serialized_start=5928
  _TTTLSETTINGS_EUNIT._serialized_end=6036
  _TTABLEDESCRIPTION._serialized_start=6049
  _TTABLEDESCRIPTION._serialized_end=6932
  _TCOMPRESSIONOPTIONS._serialized_start=6934
  _TCOMPRESSIONOPTIONS._serialized_end=7038
  _TOLAPCOLUMNDESCRIPTION._serialized_start=7041
  _TOLAPCOLUMNDESCRIPTION._serialized_end=7181
  _TALTEROLAPCOLUMN._serialized_start=7183
  _TALTEROLAPCOLUMN._serialized_end=7215
  _TDROPOLAPCOLUMN._serialized_start=7217
  _TDROPOLAPCOLUMN._serialized_end=7248
  _TSTORAGETIERCONFIG._serialized_start=7251
  _TSTORAGETIERCONFIG._serialized_end=7397
  _TCOLUMNTABLESCHEMA._serialized_start=7400
  _TCOLUMNTABLESCHEMA._serialized_end=7663
  _TALTERCOLUMNTABLESCHEMA._serialized_start=7666
  _TALTERCOLUMNTABLESCHEMA._serialized_end=7891
  _TCOLUMNTABLESCHEMAPRESET._serialized_start=7893
  _TCOLUMNTABLESCHEMAPRESET._serialized_end=7998
  _TALTERCOLUMNTABLESCHEMAPRESET._serialized_start=8000
  _TALTERCOLUMNTABLESCHEMAPRESET._serialized_end=8108
  _TREMOVECOLUMNTABLESCHEMAPRESET._serialized_start=8110
  _TREMOVECOLUMNTABLESCHEMAPRESET._serialized_end=8156
  _TCOLUMNDATALIFECYCLE._serialized_start=8159
  _TCOLUMNDATALIFECYCLE._serialized_end=8530
  _TCOLUMNDATALIFECYCLE_TTTL._serialized_start=8356
  _TCOLUMNDATALIFECYCLE_TTTL._serialized_end=8507
  _TCOLUMNDATALIFECYCLE_TDISABLED._serialized_start=5915
  _TCOLUMNDATALIFECYCLE_TDISABLED._serialized_end=5926
  _TCOLUMNTABLETTLSETTINGSPRESET._serialized_start=8532
  _TCOLUMNTABLETTLSETTINGSPRESET._serialized_end=8649
  _TALTERCOLUMNTABLETTLSETTINGSPRESET._serialized_start=8651
  _TALTERCOLUMNTABLETTLSETTINGSPRESET._serialized_end=8766
  _TREMOVECOLUMNTABLETTLSETTINGSPRESET._serialized_start=8768
  _TREMOVECOLUMNTABLETTLSETTINGSPRESET._serialized_end=8819
  _TCOLUMNSTORAGECONFIG._serialized_start=8822
  _TCOLUMNSTORAGECONFIG._serialized_end=9018
  _TCOLUMNSTORESHARDING._serialized_start=9020
  _TCOLUMNSTORESHARDING._serialized_end=9140
  _TCOLUMNSTOREDESCRIPTION._serialized_start=9143
  _TCOLUMNSTOREDESCRIPTION._serialized_end=9566
  _TALTERCOLUMNSTORE._serialized_start=9569
  _TALTERCOLUMNSTORE._serialized_end=10105
  _TCOLUMNTABLESHARDING._serialized_start=10108
  _TCOLUMNTABLESHARDING._serialized_end=10660
  _TCOLUMNTABLESHARDING_TRANDOMSHARDING._serialized_start=10387
  _TCOLUMNTABLESHARDING_TRANDOMSHARDING._serialized_end=10404
  _TCOLUMNTABLESHARDING_THASHSHARDING._serialized_start=10407
  _TCOLUMNTABLESHARDING_THASHSHARDING._serialized_end=10650
  _TCOLUMNTABLESHARDING_THASHSHARDING_EHASHFUNCTION._serialized_start=10577
  _TCOLUMNTABLESHARDING_THASHSHARDING_EHASHFUNCTION._serialized_end=10650
  _TCOLUMNTABLEDESCRIPTION._serialized_start=10663
  _TCOLUMNTABLEDESCRIPTION._serialized_end=11207
  _TALTERCOLUMNTABLE._serialized_start=11210
  _TALTERCOLUMNTABLE._serialized_end=11447
  _TLOGINCREATEUSER._serialized_start=11449
  _TLOGINCREATEUSER._serialized_end=11499
  _TLOGINMODIFYUSER._serialized_start=11501
  _TLOGINMODIFYUSER._serialized_end=11551
  _TLOGINREMOVEUSER._serialized_start=11553
  _TLOGINREMOVEUSER._serialized_end=11585
  _TLOGINCREATEGROUP._serialized_start=11587
  _TLOGINCREATEGROUP._serialized_end=11621
  _TLOGINADDGROUPMEMBERSHIP._serialized_start=11623
  _TLOGINADDGROUPMEMBERSHIP._serialized_end=11680
  _TLOGINREMOVEGROUPMEMBERSHIP._serialized_start=11682
  _TLOGINREMOVEGROUPMEMBERSHIP._serialized_end=11742
  _TLOGINREMOVEGROUP._serialized_start=11744
  _TLOGINREMOVEGROUP._serialized_end=11778
  _TALTERLOGIN._serialized_start=11781
  _TALTERLOGIN._serialized_end=12244
  _TCDCSTREAMDESCRIPTION._serialized_start=12247
  _TCDCSTREAMDESCRIPTION._serialized_end=12520
  _TCREATECDCSTREAM._serialized_start=12523
  _TCREATECDCSTREAM._serialized_end=12666
  _TALTERCDCSTREAM._serialized_start=12669
  _TALTERCDCSTREAM._serialized_end=12809
  _TALTERCDCSTREAM_TDISABLE._serialized_start=12789
  _TALTERCDCSTREAM_TDISABLE._serialized_end=12799
  _TDROPCDCSTREAM._serialized_start=12811
  _TDROPCDCSTREAM._serialized_end=12866
  _TINDEXDESCRIPTION._serialized_start=12869
  _TINDEXDESCRIPTION._serialized_end=13122
  _TINDEXCREATIONCONFIG._serialized_start=13125
  _TINDEXCREATIONCONFIG._serialized_end=13369
  _TINDEXALTERINGCONFIG._serialized_start=13371
  _TINDEXALTERINGCONFIG._serialized_end=13452
  _TINDEXEDTABLECREATIONCONFIG._serialized_start=13455
  _TINDEXEDTABLECREATIONCONFIG._serialized_end=13679
  _TINITIATEBUILDINDEXMAINTABLE._serialized_start=13681
  _TINITIATEBUILDINDEXMAINTABLE._serialized_end=13730
  _TBUILDINDEXOUTCOME._serialized_start=13733
  _TBUILDINDEXOUTCOME._serialized_end=13922
  _TBUILDINDEXOUTCOME_TCANCEL._serialized_start=13859
  _TBUILDINDEXOUTCOME_TCANCEL._serialized_end=13912
  _TFINALIZEBUILDINDEXMAINTABLE._serialized_start=13925
  _TFINALIZEBUILDINDEXMAINTABLE._serialized_end=14072
  _TCOPYTABLECONFIG._serialized_start=14075
  _TCOPYTABLECONFIG._serialized_end=14210
  _TCONSISTENTTABLECOPYINGCONFIG._serialized_start=14212
  _TCONSISTENTTABLECOPYINGCONFIG._serialized_end=14309
  _TYTSETTINGS._serialized_start=14311
  _TYTSETTINGS._serialized_end=14430
  _TS3SETTINGS._serialized_start=14433
  _TS3SETTINGS._serialized_end=15060
  _TS3SETTINGS_TLIMITS._serialized_start=14945
  _TS3SETTINGS_TLIMITS._serialized_end=15028
  _TS3SETTINGS_ESCHEME._serialized_start=15030
  _TS3SETTINGS_ESCHEME._serialized_end=15060
  _TTASKCLEANER._serialized_start=15062
  _TTASKCLEANER._serialized_end=15166
  _TBACKUPTASK._serialized_start=15169
  _TBACKUPTASK._serialized_end=15732
  _TBACKUPTASK_TSCANSETTINGS._serialized_start=15574
  _TBACKUPTASK_TSCANSETTINGS._serialized_end=15649
  _TBACKUPTASK_TCOMPRESSIONOPTIONS._serialized_start=15651
  _TBACKUPTASK_TCOMPRESSIONOPTIONS._serialized_end=15702
  _TRESTORETASK._serialized_start=15735
  _TRESTORETASK._serialized_end=15954
  _TPERSQUEUEGROUPALLOCATE._serialized_start=15957
  _TPERSQUEUEGROUPALLOCATE._serialized_end=16401
  _TPERSQUEUEGROUPALLOCATE_TPARTITION._serialized_start=16299
  _TPERSQUEUEGROUPALLOCATE_TPARTITION._serialized_end=16401
  _TPERSQUEUEGROUPDEALLOCATE._serialized_start=16403
  _TPERSQUEUEGROUPDEALLOCATE._serialized_end=16444
  _TPERSQUEUEGROUPDESCRIPTION._serialized_start=16447
  _TPERSQUEUEGROUPDESCRIPTION._serialized_end=17199
  _TPERSQUEUEGROUPDESCRIPTION_TPARTITION._serialized_start=17042
  _TPERSQUEUEGROUPDESCRIPTION_TPARTITION._serialized_end=17142
  _TPERSQUEUEGROUPDESCRIPTION_TPARTITIONTOADD._serialized_start=17144
  _TPERSQUEUEGROUPDESCRIPTION_TPARTITIONTOADD._serialized_end=17199
  _TRTMRVOLUMEDESCRIPTION._serialized_start=17202
  _TRTMRVOLUMEDESCRIPTION._serialized_end=17422
  _TRTMRVOLUMEDESCRIPTION_TPARTITION._serialized_start=17355
  _TRTMRVOLUMEDESCRIPTION_TPARTITION._serialized_end=17422
  _TBLOCKSTOREVOLUMEDESCRIPTION._serialized_start=17425
  _TBLOCKSTOREVOLUMEDESCRIPTION._serialized_end=17760
  _TBLOCKSTOREVOLUMEDESCRIPTION_TPARTITION._serialized_start=17042
  _TBLOCKSTOREVOLUMEDESCRIPTION_TPARTITION._serialized_end=17093
  _TFILESTOREDESCRIPTION._serialized_start=17763
  _TFILESTOREDESCRIPTION._serialized_end=17899
  _TKESUSDESCRIPTION._serialized_start=17902
  _TKESUSDESCRIPTION._serialized_end=18033
  _TSOLOMONVOLUMEDESCRIPTION._serialized_start=18036
  _TSOLOMONVOLUMEDESCRIPTION._serialized_end=18320
  _TSOLOMONVOLUMEDESCRIPTION_TPARTITION._serialized_start=18194
  _TSOLOMONVOLUMEDESCRIPTION_TPARTITION._serialized_end=18320
  _TCREATESOLOMONVOLUME._serialized_start=18323
  _TCREATESOLOMONVOLUME._serialized_end=18567
  _TCREATESOLOMONVOLUME_TADOPTEDPARTITION._serialized_start=18495
  _TCREATESOLOMONVOLUME_TADOPTEDPARTITION._serialized_end=18567
  _TALTERSOLOMONVOLUME._serialized_start=18569
  _TALTERSOLOMONVOLUME._serialized_end=18692
  _TBLOCKSTOREASSIGNOP._serialized_start=18694
  _TBLOCKSTOREASSIGNOP._serialized_end=18774
  _TMODIFYACL._serialized_start=18776
  _TMODIFYACL._serialized_end=18837
  _TSPLITMERGETABLEPARTITIONS._serialized_start=18840
  _TSPLITMERGETABLEPARTITIONS._serialized_end=19048
  _TUSERATTRIBUTE._serialized_start=19050
  _TUSERATTRIBUTE._serialized_end=19094
  _TALTERUSERATTRIBUTES._serialized_start=19096
  _TALTERUSERATTRIBUTES._serialized_end=19193
  _TMOVE._serialized_start=19195
  _TMOVE._serialized_end=19236
  _TMOVEINDEX._serialized_start=19238
  _TMOVEINDEX._serialized_end=19327
  _TSEQUENCEDESCRIPTION._serialized_start=19330
  _TSEQUENCEDESCRIPTION._serialized_end=19550
  _TSEQUENCESHARDING._serialized_start=19552
  _TSEQUENCESHARDING._serialized_end=19623
  _TREPLICATIONDESCRIPTION._serialized_start=19626
  _TREPLICATIONDESCRIPTION._serialized_end=19799
  _TBLOBDEPOTDESCRIPTION._serialized_start=19802
  _TBLOBDEPOTDESCRIPTION._serialized_end=19965
  _TAPPLYIF._serialized_start=19967
  _TAPPLYIF._serialized_end=20034
  _TUPGRADESUBDOMAIN._serialized_start=20037
  _TUPGRADESUBDOMAIN._serialized_end=20182
  _TUPGRADESUBDOMAIN_EDECISION._serialized_start=20136
  _TUPGRADESUBDOMAIN_EDECISION._serialized_end=20182
  _TINDEXBUILDCONFIG._serialized_start=20184
  _TINDEXBUILDCONFIG._serialized_end=20272
  _TINDEXBUILDCONTROL._serialized_start=20274
  _TINDEXBUILDCONTROL._serialized_end=20375
  _TLOCKCONFIG._serialized_start=20377
  _TLOCKCONFIG._serialized_end=20404
  _TLOCKGUARD._serialized_start=20406
  _TLOCKGUARD._serialized_end=20437
  _TDROPINDEX._serialized_start=20439
  _TDROPINDEX._serialized_end=20489
  _TMODIFYSCHEME._serialized_start=20492
  _TMODIFYSCHEME._serialized_end=23832
  _TMODIFYSCRIPT._serialized_start=23834
  _TMODIFYSCRIPT._serialized_end=23903
  _TDESCRIBEOPTIONS._serialized_start=23906
  _TDESCRIBEOPTIONS._serialized_end=24227
  _TDESCRIBEPATH._serialized_start=24230
  _TDESCRIBEPATH._serialized_end=24452
  _TPATHVERSION._serialized_start=24455
  _TPATHVERSION._serialized_end=25168
  _TDIRENTRY._serialized_start=25171
  _TDIRENTRY._serialized_end=25613
  _TTABLEPARTITION._serialized_start=25615
  _TTABLEPARTITION._serialized_end=25720
  _TSHARDERROR._serialized_start=25722
  _TSHARDERROR._serialized_end=25769
  _TBACKUPPROGRESS._serialized_start=25772
  _TBACKUPPROGRESS._serialized_end=26000
  _TLASTBACKUPRESULT._serialized_start=26003
  _TLASTBACKUPRESULT._serialized_end=26226
  _TPATHDESCRIPTION._serialized_start=26229
  _TPATHDESCRIPTION._serialized_end=27855
  _TALTEREXTRADATA._serialized_start=27857
  _TALTEREXTRADATA._serialized_end=27934
  _TRESOURCEPROFILE._serialized_start=27937
  _TRESOURCEPROFILE._serialized_end=28411
# @@protoc_insertion_point(module_scope)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table

description = 'List vdisks'


def add_options(p):
    p.add_argument('--show-pdisk-status', action='store_true', help='Show columns with PDisk statuses')
    p.add_argument('--show-vdisk-usage', action='store_true', help='Show columns with VDisk usage')
    table.TableOutput([], col_units=[]).add_options(p)


def do(args):
    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
    base_config = base_config_and_storage_pools['BaseConfig']
    storage_pools = base_config_and_storage_pools['StoragePools']

    group_map = common.build_group_map(base_config)
    node_fqdn_map = common.build_node_fqdn_map(base_config)
    pdisk_map = common.build_pdisk_map(base_config)
    vslot_map = common.build_vslot_map(base_config)

    sp_name = {
        (sp.BoxId, sp.StoragePoolId): sp.Name
        for sp in storage_pools
    }

    group_to_sp_name = {
        group_id: sp_name[group.BoxId, group.StoragePoolId]
        for group_id, group in group_map.items()
    }

    all_columns = [
        'VDiskId',
        'GroupId',
        'GroupGeneration',
        'NodeId:PDiskId',
        'FQDN',
        'NodeId',
        'PDiskId',
        'PDiskDriveStatus',
        'PDiskDecommitStatus',
        'PDiskPath',
        'VSlotId',
        'VSlotStatus',
        'IsDonor',
        'FailRealmIdx',
        'FailDomainIdx',
        'VDiskIdx',
        'VDiskKind',
        'Usage',
        'UsedSize',
        'AvailableSize',
        'TotalSize',
        'SatisfactionRank',
        'PoolName',
        'BoxId',
        'PDiskPage',
        'VDiskPage',
    ]
    visible_columns = [
        'VDiskId',
        'GroupId',
        'NodeId:PDiskId',
        'VSlotId',
        'VSlotStatus',
        'IsDonor',
    ]
    col_units = {
        'Usage': '%',
        'UsedSize': 'bytes',
        'AvailableSize': 'bytes',
        'TotalSize': 'bytes'
    }

    if args.show_pdisk_status:
        visible_columns.extend(['PDiskDriveStatus', 'PDiskDecommitStatus'])

    if args.show_vdisk_usage:
        visible_columns.extend(['Usage', 'UsedSize', 'AvailableSize', 'TotalSize'])

    table_output = table.TableOutput(all_columns, col_units=col_units, default_visible_columns=visible_columns)

    rows = []
    for group in group_map:
        for vslot_data in group_map[group].VSlotId:
            pdisk = pdisk_map[vslot_data.NodeId, vslot_data.PDiskId]
            vslot = vslot_map[common.get_vslot_id(vslot_data)]
            row = {}
            row['BoxId'] = pdisk.BoxId
            row['PoolName'] = group_to_sp_name[group]
            row['VDiskId'] = '[%08x:%u:%u:%u:%u]' % (vslot.GroupId, vslot.GroupGeneration, vslot.FailRealmIdx, vslot.FailDomainIdx, vslot.VDiskIdx)
            row['GroupId'] = group
            row['GroupGeneration'] = vslot.GroupGeneration
            row['NodeId:PDiskId'] = '[%u:%u]' % (vslot_data.NodeId, vslot_data.PDiskId)
            row['FQDN'] = node_fqdn_map[vslot_data.NodeId]
            row['NodeId'] = vslot_data.NodeId
            row['PDiskId'] = vslot_data.PDiskId
            row['PDiskDriveStatus'] = kikimr_bsconfig.EDriveStatus.Name(pdisk.DriveStatus)
            row['PDiskDecommitStatus'] = kikimr_bsconfig.EDecommitStatus.Name(pdisk.DecommitStatus)
            row['PDiskPath'] = pdisk.Path
            row['VSlotId'] = vslot_data.VSlotId
            row['VSlotStatus'] = vslot.Status
            row['IsDonor'] = group_map[group].GroupGeneration != vslot.GroupGeneration
            row['FailRealmIdx'] = vslot.FailRealmIdx
            row['FailDomainIdx'] = vslot.FailDomainIdx
            row['VDiskIdx'] = vslot.VDiskIdx
            row['VDiskKind'] = vslot.VDiskKind
            row['UsedSize'] = vslot.VDiskMetrics.AllocatedSize
            row['AvailableSize'] = vslot.VDiskMetrics.AvailableSize
            row['TotalSize'] = row['UsedSize'] + row['AvailableSize']
            row['Usage'] = row['UsedSize'] / row['TotalSize'] if row['TotalSize'] > 0 else 0.0
            row['PDiskPage'] = 'actors/pdisks/pdisk%09u' % (vslot_data.PDiskId)
            row['VDiskPage'] = 'actors/vdisks/vdisk%09u_%09u' % (vslot_data.PDiskId, vslot_data.VSlotId)
            rows.append(row)

    table_output.dump(rows, args)



# -*- coding: utf-8 -*-
import setuptools

with open("README.md", "r", encoding="utf-8") as fhand:
    long_description = fhand.read()

setuptools.setup(
    name="ydb-dstool",
    version="0.0.6",
    description="YDB Distributed Storage Administration Tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Yandex LLC",
    author_email="ydb@yandex-team.ru",
    url="https://github.com/ydb-platform/ydb/tree/main/ydb/apps/dstool",
    license="Apache 2.0",
    package_dir={"": "."},
    packages=setuptools.find_packages("."),
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
    ],
    install_requires=(
        "protobuf>=3.13.0",
        "grpcio>=1.5.0",
        "packaging"
    ),
    entry_points={
        "console_scripts": [
            "ydb-dstool = ydb.apps.dstool.cli:main",
        ]
    }
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/shared_cache.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/shared_cache.proto\x12\x12NKikimrSharedCache\"\x85\x01\n\x12TSharedCacheConfig\x12\x1e\n\x0bMemoryLimit\x18\x01 \x01(\x04:\t536870912\x12&\n\x13ScanQueueInFlyLimit\x18\x02 \x01(\x04:\t536870912\x12\'\n\x14\x41syncQueueInFlyLimit\x18\x03 \x01(\x04:\t536870912B\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.shared_cache_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSHAREDCACHECONFIG._serialized_start=59
  _TSHAREDCACHECONFIG._serialized_end=192
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/import.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_import_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__import__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/import.proto\x12\rNKikimrImport\x1a&ydb/public/api/protos/ydb_import.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xa5\x02\n\x07TImport\x12\n\n\x02Id\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x35\n\x08Progress\x18\x04 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x35\n\rItemsProgress\x18\x05 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\x12@\n\x14ImportFromS3Settings\x18\x06 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsH\x00\x42\n\n\x08Settings\"\x9e\x01\n\x14TCreateImportRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12@\n\x14ImportFromS3Settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsH\x00\x42\n\n\x08Settings\"\x83\x01\n\x16TEvCreateImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x0f\n\x07UserSID\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x04 \x01(\x0b\x32#.NKikimrImport.TCreateImportRequest\">\n\x15TCreateImportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrImport.TImport\"_\n\x17TEvCreateImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TCreateImportResponse\"\x1f\n\x11TGetImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"^\n\x13TEvGetImportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrImport.TGetImportRequest\";\n\x12TGetImportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrImport.TImport\"K\n\x14TEvGetImportResponse\x12\x33\n\x08Response\x18\x01 \x01(\x0b\x32!.NKikimrImport.TGetImportResponse\"\"\n\x14TCancelImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvCancelImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrImport.TCancelImportRequest\"k\n\x15TCancelImportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvCancelImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TCancelImportResponse\"\"\n\x14TForgetImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvForgetImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrImport.TForgetImportRequest\"k\n\x15TForgetImportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvForgetImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TForgetImportResponse\"H\n\x13TListImportsRequest\x12\x10\n\x08PageSize\x18\x01 \x01(\x04\x12\x11\n\tPageToken\x18\x02 \x01(\t\x12\x0c\n\x04Kind\x18\x03 \x01(\t\"b\n\x15TEvListImportsRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x33\n\x07Request\x18\x01 \x01(\x0b\x32\".NKikimrImport.TListImportsRequest\"\xaa\x01\n\x14TListImportsResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\x16.NKikimrImport.TImport\x12\x15\n\rNextPageToken\x18\x04 \x01(\t\"O\n\x16TEvListImportsResponse\x12\x35\n\x08Response\x18\x01 \x01(\x0b\x32#.NKikimrImport.TListImportsResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.import_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TIMPORT._serialized_start=224
  _TIMPORT._serialized_end=517
  _TCREATEIMPORTREQUEST._serialized_start=520
  _TCREATEIMPORTREQUEST._serialized_end=678
  _TEVCREATEIMPORTREQUEST._serialized_start=681
  _TEVCREATEIMPORTREQUEST._serialized_end=812
  _TCREATEIMPORTRESPONSE._serialized_start=814
  _TCREATEIMPORTRESPONSE._serialized_end=876
  _TEVCREATEIMPORTRESPONSE._serialized_start=878
  _TEVCREATEIMPORTRESPONSE._serialized_end=973
  _TGETIMPORTREQUEST._serialized_start=975
  _TGETIMPORTREQUEST._serialized_end=1006
  _TEVGETIMPORTREQUEST._serialized_start=1008
  _TEVGETIMPORTREQUEST._serialized_end=1102
  _TGETIMPORTRESPONSE._serialized_start=1104
  _TGETIMPORTRESPONSE._serialized_end=1163
  _TEVGETIMPORTRESPONSE._serialized_start=1165
  _TEVGETIMPORTRESPONSE._serialized_end=1240
  _TCANCELIMPORTREQUEST._serialized_start=1242
  _TCANCELIMPORTREQUEST._serialized_end=1276
  _TEVCANCELIMPORTREQUEST._serialized_start=1278
  _TEVCANCELIMPORTREQUEST._serialized_end=1392
  _TCANCELIMPORTRESPONSE._serialized_start=1394
  _TCANCELIMPORTRESPONSE._serialized_end=1501
  _TEVCANCELIMPORTRESPONSE._serialized_start=1503
  _TEVCANCELIMPORTRESPONSE._serialized_end=1598
  _TFORGETIMPORTREQUEST._serialized_start=1600
  _TFORGETIMPORTREQUEST._serialized_end=1634
  _TEVFORGETIMPORTREQUEST._serialized_start=1636
  _TEVFORGETIMPORTREQUEST._serialized_end=1750
  _TFORGETIMPORTRESPONSE._serialized_start=1752
  _TFORGETIMPORTRESPONSE._serialized_end=1859
  _TEVFORGETIMPORTRESPONSE._serialized_start=1861
  _TEVFORGETIMPORTRESPONSE._serialized_end=1956
  _TLISTIMPORTSREQUEST._serialized_start=1958
  _TLISTIMPORTSREQUEST._serialized_end=2030
  _TEVLISTIMPORTSREQUEST._serialized_start=2032
  _TEVLISTIMPORTSREQUEST._serialized_end=2130
  _TLISTIMPORTSRESPONSE._serialized_start=2133
  _TLISTIMPORTSRESPONSE._serialized_end=2303
  _TEVLISTIMPORTSRESPONSE._serialized_start=2305
  _TEVLISTIMPORTSRESPONSE._serialized_end=2384
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/query_stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/query_stats.proto\x12\x11NKikimrQueryStats\":\n\x0cTReadOpStats\x12\r\n\x05\x43ount\x18\x01 \x01(\x04\x12\x0c\n\x04Rows\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\";\n\rTWriteOpStats\x12\r\n\x05\x43ount\x18\x01 \x01(\x04\x12\x0c\n\x04Rows\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\"A\n\nTTableInfo\x12\x15\n\rSchemeshardId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\"\xac\x02\n\x11TTableAccessStats\x12\x30\n\tTableInfo\x18\x01 \x01(\x0b\x32\x1d.NKikimrQueryStats.TTableInfo\x12\x32\n\tSelectRow\x18\x02 \x01(\x0b\x32\x1f.NKikimrQueryStats.TReadOpStats\x12\x34\n\x0bSelectRange\x18\x03 \x01(\x0b\x32\x1f.NKikimrQueryStats.TReadOpStats\x12\x33\n\tUpdateRow\x18\x04 \x01(\x0b\x32 .NKikimrQueryStats.TWriteOpStats\x12\x32\n\x08\x45raseRow\x18\x05 \x01(\x0b\x32 .NKikimrQueryStats.TWriteOpStats\x12\x12\n\nShardCount\x18\x06 \x01(\x04\"}\n\x0eTPerShardStats\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x13\n\x0b\x43puTimeUsec\x18\x02 \x01(\x04\x12\x1d\n\x15OutgoingReadSetsCount\x18\x03 \x01(\x04\x12\x13\n\x0bProgramSize\x18\x04 \x01(\x04\x12\x11\n\tReplySize\x18\x05 \x01(\x04\"\xb4\x01\n\x08TTxStats\x12>\n\x10TableAccessStats\x18\x01 \x03(\x0b\x32$.NKikimrQueryStats.TTableAccessStats\x12\x12\n\nDurationUs\x18\x02 \x01(\x04\x12\x1a\n\x12\x43omputeCpuTimeUsec\x18\x03 \x01(\x04\x12\x38\n\rPerShardStats\x18\x04 \x03(\x0b\x32!.NKikimrQueryStats.TPerShardStatsB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.query_stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TREADOPSTATS._serialized_start=56
  _TREADOPSTATS._serialized_end=114
  _TWRITEOPSTATS._serialized_start=116
  _TWRITEOPSTATS._serialized_end=175
  _TTABLEINFO._serialized_start=177
  _TTABLEINFO._serialized_end=242
  _TTABLEACCESSSTATS._serialized_start=245
  _TTABLEACCESSSTATS._serialized_end=545
  _TPERSHARDSTATS._serialized_start=547
  _TPERSHARDSTATS._serialized_end=672
  _TTXSTATS._serialized_start=675
  _TTXSTATS._serialized_end=855
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_limits.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/node_limits.proto\x12\x11NKikimrNodeLimits\"\xc2\x01\n\x11TNodeLimitsConfig\x12V\n\x13PersQueueNodeConfig\x18\x01 \x01(\x0b\x32\x39.NKikimrNodeLimits.TNodeLimitsConfig.TPersQueueNodeConfig\x1aU\n\x14TPersQueueNodeConfig\x12\x1f\n\x11SharedCacheSizeMb\x18\x01 \x01(\x04:\x04\x38\x31\x39\x32\x12\x1c\n\x10\x43\x61\x63heKeepTimeSec\x18\x02 \x01(\r:\x02\x31\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_limits_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODELIMITSCONFIG._serialized_start=57
  _TNODELIMITSCONFIG._serialized_end=251
  _TNODELIMITSCONFIG_TPERSQUEUENODECONFIG._serialized_start=166
  _TNODELIMITSCONFIG_TPERSQUEUENODECONFIG._serialized_end=251
# @@protoc_insertion_point(module_scope)
